{
  osConfig,
  pkgs,
  config,
  ...
}: {
  #TODO: make the creation of the command file easier, for now this is a nice solution though
  systemd.user.services."set-kde-connect-commands" = {
    Install = {
      WantedBy = ["default.target"];
    };
    Service = {
      Type = "OneShot";
      ExecStart = "${pkgs.writeShellScript "set-kde-connect-commands" ''
        #!/run/current-system/sw/bin/bash
        find ${config.home.homeDirectory}/.config/kdeconnect/ -type d -name \'kdeconnect_runcommand\' -execdir cp ${builtins.toPath ./kde-connect-commands} {}+"/config" \;
      ''}";
      RemainAfterExit = true;
    };
  };
  home.file.".config/kdeconnect/config" = {
    text = ''
      [General]
      keyAlgorithm=EC
      name=${osConfig.networking.hostName}
      customDevices=10.0.0.2,10.0.0.3,10.0.0.4,10.0.0.5
    '';
    target = ".config/kdeconnect/config";
    force = true;
  };

  programs.plasma = {
    enable = true;
    desktop.mouseActions.verticalScroll = "switchVirtualDesktop";
    kscreenlocker.appearance.wallpaper = "${osConfig.stylix.image}";
    fonts = {
      fixedWidth = {
        pointSize = 11;
        family = "${osConfig.stylix.fonts.monospace.name}";
      };
      general = {
        pointSize = 11;
        family = "${osConfig.stylix.fonts.serif.name}";
      };
      menu = {
        pointSize = 11;
        family = "${osConfig.stylix.fonts.sansSerif.name}";
      };
      small = {
        pointSize = 11;
        family = "${osConfig.stylix.fonts.sansSerif.name}";
      };
      toolbar = {
        pointSize = 11;
        family = "${osConfig.stylix.fonts.sansSerif.name}";
      };
      windowTitle = {
        pointSize = 11;
        family = "${osConfig.stylix.fonts.sansSerif.name}";
      };
    };
    panels = [
      {
        alignment = "left";
        floating = true;
        height = 38;
        location = "top";
        screen = "all";
        widgets = [
          "org.kde.plasma.appmenu"
          "org.kde.plasma.panelspacer"
          "org.kde.milou"
          "org.kde.plasma.panelspacer"
          "org.kde.plasma.colorpicker"
          {
            systemTray.items = {
              # We explicitly show bluetooth and battery
              shown = [
                "org.kde.plasma.volume"
                "org.kde.plasma.bluetooth"
                "org.kde.plasma.brightness"
                "org.kde.plasma.devicenotifier"
                "org.kde.kscreen"
                "org.kde.kdeconnect"
                "org.kde.plasma.networkmanagement"
                "org.kde.plasma.battery"
                "org.kde.plasma.clipboard"
                "org.kde.plasma.mediacontroller"
                "org.kde.plasma.notifications"
                "org.kde.plasma.weather"
              ];
              # And explicitly hide networkmanagement and volume
              hidden = [
                "Xwayland Video Bridge_pipewireToXProxy"
                "org.kde.plasma.devicenotifier"
                "org.kde.kscreen"
                "org.kde.plasma.printmanager"
                "chrome_status_icon_1"
                "proton-vpn-app"
                "Nitrokey App"
                "qBittorrent"
                "vlc"
                "steam"
                "nitrokey-app"
              ];
            };
          }
          {
            digitalClock = {
              calendar.firstDayOfWeek = "monday";
              time.format = "24h";
              date = {
                enable = true;
                format = "isoDate";
                position = "belowTime";
              };
              timeZone.selected = ["Europe/Amsterdam"];
            };
          }
          "org.kde.plasma.lock_logout"
        ];
      }
      {
        alignment = "center";
        floating = true;
        height = 44;
        hiding = "autohide";
        maxLength = 1920;
        minLength = 1200;
        location = "bottom";
        screen = "all";
        widgets = [
          "org.kde.plasma.kickoff"
          "org.kde.plasma.panelspacer"
          {
            name = "org.kde.plasma.icontasks";
            config = {
              General = {
                launchers = [
                  "applications:librewolf.desktop"
                  "applications:systemsettings.desktop"
                  "applications:org.kde.dolphin.desktop"
                  "applications:signal.desktop"
                  "applications:vesktop.desktop"
                  "applications:thunderbird.desktop"
                  "applications:cinny.desktop"
                  "applications:steam.desktop"
                  "applications:noisetorch.desktop"
                  "applications:org.kde.plasma-systemmonitor.desktop"
                  "applications:foot.desktop"
                  "applications:nitrokey-app.desktop"
                  "applications:freetube.desktop"
                ];
              };
            };
          }
          "org.kde.plasma.panelspacer"
          "org.kde.plasma.minimizeall"
        ];
      }
    ];

    shortcuts = {
      "ActivityManager"."switch-to-activity-a2cd7f51-1f1f-47a8-9544-a4c401f57a12" = [];
      "KDE Keyboard Layout Switcher"."Switch to Last-Used Keyboard Layout" = "Meta+Alt+L";
      "KDE Keyboard Layout Switcher"."Switch to Next Keyboard Layout" = "Meta+Alt+K";
      "kaccess"."Toggle Screen Reader On and Off" = "Meta+Alt+S";
      "kcm_touchpad"."Disable Touchpad" = "Touchpad Off";
      "kcm_touchpad"."Enable Touchpad" = "Touchpad On";
      "kcm_touchpad"."Toggle Touchpad" = ["Touchpad Toggle" "" "Meta+Ctrl+Zenkaku Hankaku,Touchpad Toggle" "Meta+Ctrl+Zenkaku Hankaku"];
      "khotkeys"."{d03619b6-9b3c-48cc-9d9c-a2aadb485550}" = [];
      "kmix"."decrease_microphone_volume" = "Microphone Volume Down";
      "kmix"."decrease_volume" = "Volume Down";
      "kmix"."decrease_volume_small" = "Shift+Volume Down";
      "kmix"."increase_microphone_volume" = "Microphone Volume Up";
      "kmix"."increase_volume" = "Volume Up";
      "kmix"."increase_volume_small" = "Shift+Volume Up";
      "kmix"."mic_mute" = ["Microphone Mute" "Meta+Volume Mute,Microphone Mute" "Meta+Volume Mute,Mute Microphone"];
      "kmix"."mute" = "Volume Mute";
      "ksmserver"."Halt Without Confirmation" = "none,,Shut Down Without Confirmation";
      "ksmserver"."Lock Session" = ["Meta+L" "Screensaver,Meta+L" "Screensaver,Lock Session"];
      "ksmserver"."Log Out" = "Ctrl+Alt+Del";
      "ksmserver"."Log Out Without Confirmation" = "none,,Log Out Without Confirmation";
      "ksmserver"."LogOut" = "none,,Log Out";
      "ksmserver"."Reboot" = "none,,Reboot";
      "ksmserver"."Reboot Without Confirmation" = "none,,Reboot Without Confirmation";
      "ksmserver"."Shut Down" = "none,,Shut Down";
      "kwin"."Activate Window Demanding Attention" = "Meta+Ctrl+A";
      "kwin"."Edit Tiles" = "Meta+T";
      "kwin"."Expose" = "Ctrl+F9";
      "kwin"."ExposeAll" = ["Ctrl+F10" "Launch (C),Ctrl+F10" "Launch (C),Toggle Present Windows (All desktops)"];
      "kwin"."ExposeClass" = "Ctrl+F7";
      "kwin"."Grid View" = "Meta+G";
      "kwin"."Increase Opacity" = "none,,Increase Opacity of Active Window by 5%";
      "kwin"."Kill Window" = "Meta+Ctrl+Esc";
      "kwin"."MoveMouseToCenter" = "Meta+F6";
      "kwin"."MoveMouseToFocus" = "Meta+F5";
      "kwin"."Overview" = "Meta+W";
      "kwin"."Setup Window Shortcut" = "none,,Setup Window Shortcut";
      "kwin"."Show Desktop" = "Meta+D";
      "kwin"."Switch One Desktop Down" = "Meta+Ctrl+Down";
      "kwin"."Switch One Desktop Up" = "Meta+Ctrl+Up";
      "kwin"."Switch One Desktop to the Left" = "Meta+Ctrl+Left";
      "kwin"."Switch One Desktop to the Right" = "Meta+Ctrl+Right";
      "kwin"."Switch Window Down" = "Meta+Alt+Down";
      "kwin"."Switch Window Left" = "Meta+Alt+Left";
      "kwin"."Switch Window Right" = "Meta+Alt+Right";
      "kwin"."Switch Window Up" = "Meta+Alt+Up";
      "kwin"."Switch to Desktop 1" = "Ctrl+F1";
      "kwin"."Switch to Desktop 2" = "Ctrl+F2";
      "kwin"."Switch to Desktop 3" = "Ctrl+F3";
      "kwin"."Switch to Desktop 4" = "Ctrl+F4";
      "kwin"."Walk Through Windows" = "Alt+Tab";
      "kwin"."Walk Through Windows (Reverse)" = "Alt+Shift+Tab";
      "kwin"."Walk Through Windows of Current Application" = "Alt+`";
      "kwin"."Walk Through Windows of Current Application (Reverse)" = "Alt+~";
      "kwin"."Window Close" = "Alt+F4";
      "kwin"."Window Maximize" = "Meta+PgUp";
      "kwin"."Window Minimize" = "Meta+PgDown";
      "kwin"."Window One Desktop Down" = "Meta+Ctrl+Shift+Down";
      "kwin"."Window One Desktop Up" = "Meta+Ctrl+Shift+Up";
      "kwin"."Window One Desktop to the Left" = "Meta+Ctrl+Shift+Left";
      "kwin"."Window One Desktop to the Right" = "Meta+Ctrl+Shift+Right";
      "kwin"."Window Operations Menu" = "Alt+F3";
      "kwin"."Window Quick Tile Bottom" = "Meta+Down";
      "kwin"."Window Quick Tile Left" = "Meta+Left";
      "kwin"."Window Quick Tile Right" = "Meta+Right";
      "kwin"."Window Quick Tile Top" = "Meta+Up";
      "kwin"."Window to Next Screen" = "Meta+Shift+Right";
      "kwin"."Window to Previous Desktop" = "none,,Window to Previous Desktop";
      "kwin"."Window to Previous Screen" = "Meta+Shift+Left";
      "kwin"."view_actual_size" = "\\, Meta+0\\, ,Meta+0,Zoom to Actual Size";
      "kwin"."view_zoom_in" = ["Meta++" "Meta+=,Meta++" "Meta+=,Zoom In"];
      "kwin"."view_zoom_out" = "Meta+-";
      "mediacontrol"."nextmedia" = "Media Next";
      "mediacontrol"."pausemedia" = "Media Pause";
      "mediacontrol"."playpausemedia" = "Media Play";
      "mediacontrol"."previousmedia" = "Media Previous";
      "mediacontrol"."stopmedia" = "Media Stop";
      "org_kde_powerdevil"."Decrease Keyboard Brightness" = "Keyboard Brightness Down";
      "org_kde_powerdevil"."Decrease Screen Brightness" = ["Monitor Brightness Down" "Ctrl+Volume Down"];
      "org_kde_powerdevil"."Decrease Screen Brightness Small" = ["Monitor Brightness Down" "Ctrl+Shift+Volume Down"];
      "org_kde_powerdevil"."Hibernate" = "Hibernate";
      "org_kde_powerdevil"."Increase Keyboard Brightness" = "Keyboard Brightness Up";
      "org_kde_powerdevil"."Increase Screen Brightness" = ["Monitor Brightness Up" "Ctrl+Volume Up"];
      "org_kde_powerdevil"."Increase Screen Brightness Small" = ["Shift+Monitor Brightness Up" "Ctrl+Shift+Volume Up"];
      "org_kde_powerdevil"."PowerDown" = "Power Down";
      "org_kde_powerdevil"."PowerOff" = "Power Off";
      "org_kde_powerdevil"."Sleep" = "Sleep";
      "org_kde_powerdevil"."Toggle Keyboard Backlight" = "Keyboard Light On/Off";
      "org_kde_powerdevil"."powerProfile" = ["Battery" "Meta+B,Battery" "Meta+B,Switch Power Profile"];
      "plasmashell"."activate application launcher" = ["Meta" "Alt+F1,Meta" "Alt+F1,Activate Application Launcher"];
      "plasmashell"."activate task manager entry 1" = "Meta+1";
      "plasmashell"."activate task manager entry 10" = ",Meta+0,Activate Task Manager Entry 10";
      "plasmashell"."activate task manager entry 2" = "Meta+2";
      "plasmashell"."activate task manager entry 3" = "Meta+3";
      "plasmashell"."activate task manager entry 4" = "Meta+4";
      "plasmashell"."activate task manager entry 5" = "Meta+5";
      "plasmashell"."activate task manager entry 6" = "Meta+6";
      "plasmashell"."activate task manager entry 7" = "Meta+7";
      "plasmashell"."activate task manager entry 8" = "Meta+8";
      "plasmashell"."activate task manager entry 9" = "Meta+9";
      "plasmashell"."clear-history" = "none,,Clear Clipboard History";
      "plasmashell"."clipboard_action" = "Meta+Ctrl+X";
      "plasmashell"."cycle-panels" = "Meta+Alt+P";
      "plasmashell"."edit_clipboard" = [];
      "plasmashell"."manage activities" = "Meta+Q";
      "plasmashell"."repeat_action" = "Meta+Ctrl+R";
      "plasmashell"."show dashboard" = "Ctrl+F12";
      "plasmashell"."show-on-mouse-pos" = "Meta+V";
      "plasmashell"."stop current activity" = "Meta+S";
      "services/org.kde.krunner.desktop"."_launch" = ["Alt+Space" "Alt+F2" "Ctrl+Shift+Space" "Search"];
      "services/org.kde.plasma-systemmonitor.desktop"."_launch" = "Ctrl+Esc";
      "services/org.kde.spectacle.desktop"."ActiveWindowScreenShot" = ["Meta+Print" "Ctrl+!"];
      "services/org.kde.spectacle.desktop"."CurrentMonitorScreenShot" = "Ctrl+#";
      "services/org.kde.spectacle.desktop"."FullScreenScreenShot" = ["Ctrl+$" "Shift+Print"];
      "services/org.kde.spectacle.desktop"."OpenWithoutScreenshot" = "Ctrl+^";
      "services/org.kde.spectacle.desktop"."RectangularRegionScreenShot" = ["Ctrl+@" "Meta+Shift+Print"];
      "services/org.kde.spectacle.desktop"."WindowUnderCursorScreenShot" = ["Meta+Ctrl+Print" "Ctrl+%"];
      "services/org.kde.spectacle.desktop"."_launch" = "Print";
      "services/services.org.kde.plasma-systemmonitor.desktop"."_launch" = "Ctrl+Esc";
      "services/services.org.kde.spectacle.desktop"."ActiveWindowScreenShot" = ["" "" "" "" "" "" "Meta+Print" "Ctrl+!"];
      "services/services.org.kde.spectacle.desktop"."CurrentMonitorScreenShot" = "Ctrl+#";
      "services/services.org.kde.spectacle.desktop"."FullScreenScreenShot" = ["" "" "" "" "" "" "Ctrl+$" "Shift+Print"];
      "services/services.org.kde.spectacle.desktop"."OpenWithoutScreenshot" = "Ctrl+^";
      "services/services.org.kde.spectacle.desktop"."RecordWindow" = [];
      "services/services.org.kde.spectacle.desktop"."RectangularRegionScreenShot" = ["" "" "" "" "" "" "Ctrl+@" "Meta+Shift+Print"];
      "services/services.org.kde.spectacle.desktop"."WindowUnderCursorScreenShot" = ["" "" "" "" "" "" "Meta+Ctrl+Print" "Ctrl+%"];
      "services/services.org.kde.spectacle.desktop"."_launch" = "Print";
      "services/services.services.org.kde.plasma-systemmonitor.desktop"."_launch" = "Ctrl+Esc";
      "services/services.services.org.kde.spectacle.desktop"."ActiveWindowScreenShot" = ["" "" "" "" "" "" "" "Meta+Print" "Ctrl+!"];
      "services/services.services.org.kde.spectacle.desktop"."CurrentMonitorScreenShot" = "Ctrl+#";
      "services/services.services.org.kde.spectacle.desktop"."FullScreenScreenShot" = ["" "" "" "" "" "" "" "Ctrl+$" "Shift+Print"];
      "services/services.services.org.kde.spectacle.desktop"."OpenWithoutScreenshot" = "Ctrl+^";
      "services/services.services.org.kde.spectacle.desktop"."RecordWindow" = [];
      "services/services.services.org.kde.spectacle.desktop"."RectangularRegionScreenShot" = ["" "" "" "" "" "" "" "Ctrl+@" "Meta+Shift+Print"];
      "services/services.services.org.kde.spectacle.desktop"."WindowUnderCursorScreenShot" = ["" "" "" "" "" "" "" "Meta+Ctrl+Print" "Ctrl+%"];
      "services/services.services.org.kde.spectacle.desktop"."_launch" = "Print";
    };
    configFile = {
      "baloofilerc"."General"."dbVersion" = 2;
      "baloofilerc"."General"."exclude filters" = "*~,*.part,*.o,*.la,*.lo,*.loT,*.moc,moc_*.cpp,qrc_*.cpp,ui_*.h,cmake_install.cmake,CMakeCache.txt,CTestTestfile.cmake,libtool,config.status,confdefs.h,autom4te,conftest,confstat,Makefile.am,*.gcode,.ninja_deps,.ninja_log,build.ninja,*.csproj,*.m4,*.rej,*.gmo,*.pc,*.omf,*.aux,*.tmp,*.po,*.vm*,*.nvram,*.rcore,*.swp,*.swap,lzo,litmain.sh,*.orig,.histfile.*,.xsession-errors*,*.map,*.so,*.a,*.db,*.qrc,*.ini,*.init,*.img,*.vdi,*.vbox*,vbox.log,*.qcow2,*.vmdk,*.vhd,*.vhdx,*.sql,*.sql.gz,*.ytdl,*.class,*.pyc,*.pyo,*.elc,*.qmlc,*.jsc,*.fastq,*.fq,*.gb,*.fasta,*.fna,*.gbff,*.faa,po,CVS,.svn,.git,_darcs,.bzr,.hg,CMakeFiles,CMakeTmp,CMakeTmpQmake,.moc,.obj,.pch,.uic,.npm,.yarn,.yarn-cache,__pycache__,node_modules,node_packages,nbproject,.venv,venv,core-dumps,lost+found";
      "baloofilerc"."General"."exclude filters version" = 8;
      "dolphinrc"."ExtractDialog"."1536x864 screen: Height" = 560;
      "dolphinrc"."ExtractDialog"."1536x864 screen: Width" = 1024;
      "dolphinrc"."ExtractDialog"."1920x1080 screen: Height" = 540;
      "dolphinrc"."ExtractDialog"."1920x1080 screen: Width" = 1260;
      "dolphinrc"."ExtractDialog"."DirHistoryx5b$ex5d" = "/home/";
      "dolphinrc"."General"."RememberOpenedTabs" = false;
      "dolphinrc"."General"."ViewPropsTimestamp" = "2024,8,28,22,44,37.273";
      "dolphinrc"."IconsMode"."PreviewSize" = 80;
      "dolphinrc"."KFileDialog Settings"."Places Icons Auto-resize" = false;
      "dolphinrc"."KFileDialog Settings"."Places Icons Static Size" = 22;
      "dolphinrc"."KFileDialog Settings"."detailViewIconSize" = 16;
      "dolphinrc"."PreviewSettings"."Plugins" = "mobithumbnail,fontthumbnail,ebookthumbnail,kraorathumbnail,jpegthumbnail,windowsexethumbnail,comicbookthumbnail,djvuthumbnail,opendocumentthumbnail,windowsimagethumbnail,exrthumbnail,audiothumbnail,cursorthumbnail,svgthumbnail,blenderthumbnail,gsthumbnail,rawthumbnail,ffmpegthumbs,imagethumbnail,directorythumbnail";
      "dolphinrc"."Search"."Location" = "Everywhere";
      "kactivitymanagerdrc"."activities"."a2cd7f51-1f1f-47a8-9544-a4c401f57a12" = "Default";
      "kactivitymanagerdrc"."main"."currentActivity" = "a2cd7f51-1f1f-47a8-9544-a4c401f57a12";
      "katerc"."General"."Days Meta Infos" = 30;
      "katerc"."General"."Save Meta Infos" = true;
      "katerc"."General"."Show Full Path in Title" = false;
      "katerc"."General"."Show Menu Bar" = true;
      "katerc"."General"."Show Status Bar" = true;
      "katerc"."General"."Show Tab Bar" = true;
      "katerc"."General"."Show Url Nav Bar" = true;
      "katerc"."KTextEditor Document"."Allow End of Line Detection" = true;
      "katerc"."KTextEditor Document"."Auto Detect Indent" = true;
      "katerc"."KTextEditor Document"."Auto Reload If State Is In Version Control" = true;
      "katerc"."KTextEditor Document"."Auto Save" = false;
      "katerc"."KTextEditor Document"."Auto Save Interval" = 0;
      "katerc"."KTextEditor Document"."Auto Save On Focus Out" = false;
      "katerc"."KTextEditor Document"."BOM" = false;
      "katerc"."KTextEditor Document"."Backup Local" = false;
      "katerc"."KTextEditor Document"."Backup Prefix" = "";
      "katerc"."KTextEditor Document"."Backup Remote" = false;
      "katerc"."KTextEditor Document"."Backup Suffix" = "~";
      "katerc"."KTextEditor Document"."Camel Cursor" = true;
      "katerc"."KTextEditor Document"."Encoding" = "UTF-8";
      "katerc"."KTextEditor Document"."End of Line" = 0;
      "katerc"."KTextEditor Document"."Indent On Backspace" = true;
      "katerc"."KTextEditor Document"."Indent On Tab" = true;
      "katerc"."KTextEditor Document"."Indent On Text Paste" = false;
      "katerc"."KTextEditor Document"."Indentation Mode" = "normal";
      "katerc"."KTextEditor Document"."Indentation Width" = 4;
      "katerc"."KTextEditor Document"."Keep Extra Spaces" = false;
      "katerc"."KTextEditor Document"."Line Length Limit" = 10000;
      "katerc"."KTextEditor Document"."Newline at End of File" = true;
      "katerc"."KTextEditor Document"."On-The-Fly Spellcheck" = false;
      "katerc"."KTextEditor Document"."Overwrite Mode" = false;
      "katerc"."KTextEditor Document"."PageUp/PageDown Moves Cursor" = false;
      "katerc"."KTextEditor Document"."Remove Spaces" = 1;
      "katerc"."KTextEditor Document"."ReplaceTabsDyn" = true;
      "katerc"."KTextEditor Document"."Show Spaces" = 0;
      "katerc"."KTextEditor Document"."Show Tabs" = true;
      "katerc"."KTextEditor Document"."Smart Home" = true;
      "katerc"."KTextEditor Document"."Swap Directory" = "";
      "katerc"."KTextEditor Document"."Swap File Mode" = 1;
      "katerc"."KTextEditor Document"."Swap Sync Interval" = 15;
      "katerc"."KTextEditor Document"."Tab Handling" = 2;
      "katerc"."KTextEditor Document"."Tab Width" = 4;
      "katerc"."KTextEditor Document"."Trailing Marker Size" = 1;
      "katerc"."KTextEditor Document"."Word Wrap" = false;
      "katerc"."KTextEditor Document"."Word Wrap Column" = 80;
      "katerc"."KTextEditor Editor"."Encoding Prober Type" = 1;
      "katerc"."KTextEditor Editor"."Fallback Encoding" = "ISO 8859-15";
      "katerc"."KTextEditor Renderer"."Animate Bracket Matching" = false;
      "katerc"."KTextEditor Renderer"."Auto Color Theme Selection" = true;
      "katerc"."KTextEditor Renderer"."Color Theme" = "Catppuccin Macchiato";
      "katerc"."KTextEditor Renderer"."Font" = "Hack,10,-1,7,50,0,0,0,0,0";
      "katerc"."KTextEditor Renderer"."Line Height Multiplier" = 1;
      "katerc"."KTextEditor Renderer"."Show Indentation Lines" = false;
      "katerc"."KTextEditor Renderer"."Show Whole Bracket Expression" = false;
      "katerc"."KTextEditor Renderer"."Word Wrap Marker" = false;
      "katerc"."KTextEditor View"."Allow Mark Menu" = true;
      "katerc"."KTextEditor View"."Auto Brackets" = true;
      "katerc"."KTextEditor View"."Auto Center Lines" = 0;
      "katerc"."KTextEditor View"."Auto Completion" = true;
      "katerc"."KTextEditor View"."Auto Completion Preselect First Entry" = true;
      "katerc"."KTextEditor View"."Backspace Remove Composed Characters" = false;
      "katerc"."KTextEditor View"."Bookmark Menu Sorting" = 0;
      "katerc"."KTextEditor View"."Bracket Match Preview" = false;
      "katerc"."KTextEditor View"."Chars To Enclose Selection" = "<>(){}x5bx5d'\"";
      "katerc"."KTextEditor View"."Default Mark Type" = 1;
      "katerc"."KTextEditor View"."Dynamic Word Wrap" = true;
      "katerc"."KTextEditor View"."Dynamic Word Wrap Align Indent" = 80;
      "katerc"."KTextEditor View"."Dynamic Word Wrap At Static Marker" = false;
      "katerc"."KTextEditor View"."Dynamic Word Wrap Indicators" = 1;
      "katerc"."KTextEditor View"."Dynamic Wrap not at word boundaries" = false;
      "katerc"."KTextEditor View"."Enable Tab completion" = false;
      "katerc"."KTextEditor View"."Fold First Line" = false;
      "katerc"."KTextEditor View"."Folding Bar" = true;
      "katerc"."KTextEditor View"."Folding Preview" = true;
      "katerc"."KTextEditor View"."Icon Bar" = false;
      "katerc"."KTextEditor View"."Input Mode" = 0;
      "katerc"."KTextEditor View"."Keyword Completion" = true;
      "katerc"."KTextEditor View"."Line Modification" = true;
      "katerc"."KTextEditor View"."Line Numbers" = true;
      "katerc"."KTextEditor View"."Max Clipboard History Entries" = 20;
      "katerc"."KTextEditor View"."Maximum Search History Size" = 100;
      "katerc"."KTextEditor View"."Mouse Paste At Cursor Position" = false;
      "katerc"."KTextEditor View"."Multiple Cursor Modifier" = 134217728;
      "katerc"."KTextEditor View"."Persistent Selection" = false;
      "katerc"."KTextEditor View"."Scroll Bar Marks" = false;
      "katerc"."KTextEditor View"."Scroll Bar Mini Map All" = true;
      "katerc"."KTextEditor View"."Scroll Bar Mini Map Width" = 60;
      "katerc"."KTextEditor View"."Scroll Bar MiniMap" = true;
      "katerc"."KTextEditor View"."Scroll Bar Preview" = true;
      "katerc"."KTextEditor View"."Scroll Past End" = false;
      "katerc"."KTextEditor View"."Search/Replace Flags" = 140;
      "katerc"."KTextEditor View"."Shoe Line Ending Type in Statusbar" = false;
      "katerc"."KTextEditor View"."Show Documentation With Completion" = true;
      "katerc"."KTextEditor View"."Show File Encoding" = true;
      "katerc"."KTextEditor View"."Show Focus Frame Around Editor" = true;
      "katerc"."KTextEditor View"."Show Folding Icons On Hover Only" = true;
      "katerc"."KTextEditor View"."Show Line Count" = false;
      "katerc"."KTextEditor View"."Show Scrollbars" = 0;
      "katerc"."KTextEditor View"."Show Statusbar Dictionary" = true;
      "katerc"."KTextEditor View"."Show Statusbar Highlighting Mode" = true;
      "katerc"."KTextEditor View"."Show Statusbar Input Mode" = true;
      "katerc"."KTextEditor View"."Show Statusbar Line Column" = true;
      "katerc"."KTextEditor View"."Show Statusbar Tab Settings" = true;
      "katerc"."KTextEditor View"."Show Word Count" = false;
      "katerc"."KTextEditor View"."Smart Copy Cut" = true;
      "katerc"."KTextEditor View"."Statusbar Line Column Compact Mode" = true;
      "katerc"."KTextEditor View"."Text Drag And Drop" = true;
      "katerc"."KTextEditor View"."User Sets Of Chars To Enclose Selection" = "";
      "katerc"."KTextEditor View"."Vi Input Mode Steal Keys" = false;
      "katerc"."KTextEditor View"."Vi Relative Line Numbers" = false;
      "katerc"."KTextEditor View"."Word Completion" = true;
      "katerc"."KTextEditor View"."Word Completion Minimal Word Length" = 3;
      "katerc"."KTextEditor View"."Word Completion Remove Tail" = true;
      "katerc"."KTextEditor::Search"."Search History" = "uuid";
      "katerc"."filetree"."editShade" = "93,62,114";
      "katerc"."filetree"."listMode" = false;
      "katerc"."filetree"."shadingEnabled" = true;
      "katerc"."filetree"."showCloseButton" = false;
      "katerc"."filetree"."showFullPathOnRoots" = false;
      "katerc"."filetree"."showToolbar" = true;
      "katerc"."filetree"."sortRole" = 0;
      "katerc"."filetree"."viewShade" = "101,69,143";
      "kcminputrc"."Libinput.1739.30383.CUST0001:00 06CB:76AF Touchpad"."MiddleButtonEmulation" = true;
      "kcminputrc"."Libinput.1739.30383.CUST0001:00 06CB:76AF Touchpad"."NaturalScroll" = true;
      "kcminputrc"."Libinput.1739.30383.CUST0001:00 06CB:76AF Touchpad"."TapToClick" = true;
      "kcminputrc"."Libinput/1739/30383/CUST0001:00 06CB:76AF Touchpad"."MiddleButtonEmulation" = true;
      "kcminputrc"."Libinput/1739/30383/CUST0001:00 06CB:76AF Touchpad"."NaturalScroll" = true;
      "kcminputrc"."Libinput/1739/30383/CUST0001:00 06CB:76AF Touchpad"."TapToClick" = true;
      "kcminputrc"."Mouse"."cursorSize" = 32;
      "kcminputrc"."Tmp"."update_info" = "delete_cursor_old_default_size.upd:DeleteCursorOldDefaultSize";
      "kded5rc"."Module-browserintegrationreminder"."autoload" = false;
      "kded5rc"."Module-device_automounter"."autoload" = false;
      "kded5rc"."PlasmaBrowserIntegration"."shownCount" = 1;
      "kdeglobals"."DirSelect Dialog"."DirSelectDialog Size" = "960,540";
      "kdeglobals"."General"."AccentColor" = "184,117,220";
      "kdeglobals"."General"."AllowKDEAppsToRememberWindowPositions" = true;
      "kdeglobals"."General"."BrowserApplication" = "firefox.desktop";
      "kdeglobals"."General"."LastUsedCustomAccentColor" = "184,117,220";
      "kdeglobals"."General"."TerminalApplication" = "foot";
      "kdeglobals"."General"."TerminalService" = "org.codeberg.dnkl.foot.desktop";
      "kdeglobals"."General"."XftAntialias" = true;
      "kdeglobals"."General"."XftHintStyle" = "hintslight";
      "kdeglobals"."General"."XftSubPixel" = "rgb";
      "kdeglobals"."KDE"."AnimationDurationFactor" = 0.7071067811865475;
      "kdeglobals"."KDE"."ShowDeleteCommand" = false;
      "kdeglobals"."KDE"."SingleClick" = false;
      "kdeglobals"."KFileDialog Settings"."Allow Expansion" = false;
      "kdeglobals"."KFileDialog Settings"."Automatically select filename extension" = true;
      "kdeglobals"."KFileDialog Settings"."Breadcrumb Navigation" = false;
      "kdeglobals"."KFileDialog Settings"."Decoration position" = 2;
      "kdeglobals"."KFileDialog Settings"."LocationCombo Completionmode" = 5;
      "kdeglobals"."KFileDialog Settings"."PathCombo Completionmode" = 5;
      "kdeglobals"."KFileDialog Settings"."Show Bookmarks" = false;
      "kdeglobals"."KFileDialog Settings"."Show Full Path" = false;
      "kdeglobals"."KFileDialog Settings"."Show Inline Previews" = true;
      "kdeglobals"."KFileDialog Settings"."Show Preview" = false;
      "kdeglobals"."KFileDialog Settings"."Show Speedbar" = true;
      "kdeglobals"."KFileDialog Settings"."Show hidden files" = false;
      "kdeglobals"."KFileDialog Settings"."Sort by" = "Date";
      "kdeglobals"."KFileDialog Settings"."Sort directories first" = true;
      "kdeglobals"."KFileDialog Settings"."Sort hidden files last" = false;
      "kdeglobals"."KFileDialog Settings"."Sort reversed" = false;
      "kdeglobals"."KFileDialog Settings"."Speedbar Width" = 138;
      "kdeglobals"."KFileDialog Settings"."View Style" = "DetailTree";
      "kdeglobals"."KShortcutsDialog Settings"."Dialog Size" = "600,480";
      "kdeglobals"."PreviewSettings"."MaximumRemoteSize" = 0;
      "kdeglobals"."WM"."activeBackground" = "49,54,59";
      "kdeglobals"."WM"."activeBlend" = "252,252,252";
      "kdeglobals"."WM"."activeForeground" = "252,252,252";
      "kdeglobals"."WM"."inactiveBackground" = "42,46,50";
      "kdeglobals"."WM"."inactiveBlend" = "161,169,177";
      "kdeglobals"."WM"."inactiveForeground" = "161,169,177";
      "khotkeysrc"."Data"."DataCount" = 3;
      "khotkeysrc"."Data_1"."Comment" = "KMenuEdit Global Shortcuts";
      "khotkeysrc"."Data_1"."DataCount" = 1;
      "khotkeysrc"."Data_1"."Enabled" = true;
      "khotkeysrc"."Data_1"."Name" = "KMenuEdit";
      "khotkeysrc"."Data_1"."SystemGroup" = 1;
      "khotkeysrc"."Data_1"."Type" = "ACTION_DATA_GROUP";
      "khotkeysrc"."Data_1Conditions"."Comment" = "";
      "khotkeysrc"."Data_1Conditions"."ConditionsCount" = 0;
      "khotkeysrc"."Data_1_1"."Comment" = "Comment";
      "khotkeysrc"."Data_1_1"."Enabled" = true;
      "khotkeysrc"."Data_1_1"."Name" = "Search";
      "khotkeysrc"."Data_1_1"."Type" = "SIMPLE_ACTION_DATA";
      "khotkeysrc"."Data_1_1Actions"."ActionsCount" = 1;
      "khotkeysrc"."Data_1_1Actions0"."CommandURL" = "http://google.com";
      "khotkeysrc"."Data_1_1Actions0"."Type" = "COMMAND_URL";
      "khotkeysrc"."Data_1_1Conditions"."Comment" = "";
      "khotkeysrc"."Data_1_1Conditions"."ConditionsCount" = 0;
      "khotkeysrc"."Data_1_1Triggers"."Comment" = "Simple_action";
      "khotkeysrc"."Data_1_1Triggers"."TriggersCount" = 1;
      "khotkeysrc"."Data_1_1Triggers0"."Key" = "";
      "khotkeysrc"."Data_1_1Triggers0"."Type" = "SHORTCUT";
      "khotkeysrc"."Data_1_1Triggers0"."Uuid" = "{d03619b6-9b3c-48cc-9d9c-a2aadb485550}";
      "khotkeysrc"."Data_2"."Comment" = "This group contains various examples demonstrating most of the features of KHotkeys. (Note that this group and all its actions are disabled by default.)";
      "khotkeysrc"."Data_2"."DataCount" = 8;
      "khotkeysrc"."Data_2"."Enabled" = false;
      "khotkeysrc"."Data_2"."ImportId" = "kde32b1";
      "khotkeysrc"."Data_2"."Name" = "Examples";
      "khotkeysrc"."Data_2"."SystemGroup" = 0;
      "khotkeysrc"."Data_2"."Type" = "ACTION_DATA_GROUP";
      "khotkeysrc"."Data_2Conditions"."Comment" = "";
      "khotkeysrc"."Data_2Conditions"."ConditionsCount" = 0;
      "khotkeysrc"."Data_2_1"."Comment" = "After pressing Ctrl+Alt+I, the KSIRC window will be activated, if it exists. Simple.";
      "khotkeysrc"."Data_2_1"."Enabled" = false;
      "khotkeysrc"."Data_2_1"."Name" = "Activate KSIRC Window";
      "khotkeysrc"."Data_2_1"."Type" = "SIMPLE_ACTION_DATA";
      "khotkeysrc"."Data_2_1Actions"."ActionsCount" = 1;
      "khotkeysrc"."Data_2_1Actions0"."Type" = "ACTIVATE_WINDOW";
      "khotkeysrc"."Data_2_1Actions0Window"."Comment" = "KSIRC window";
      "khotkeysrc"."Data_2_1Actions0Window"."WindowsCount" = 1;
      "khotkeysrc"."Data_2_1Actions0Window0"."Class" = "ksirc";
      "khotkeysrc"."Data_2_1Actions0Window0"."ClassType" = 1;
      "khotkeysrc"."Data_2_1Actions0Window0"."Comment" = "KSIRC";
      "khotkeysrc"."Data_2_1Actions0Window0"."Role" = "";
      "khotkeysrc"."Data_2_1Actions0Window0"."RoleType" = 0;
      "khotkeysrc"."Data_2_1Actions0Window0"."Title" = "";
      "khotkeysrc"."Data_2_1Actions0Window0"."TitleType" = 0;
      "khotkeysrc"."Data_2_1Actions0Window0"."Type" = "SIMPLE";
      "khotkeysrc"."Data_2_1Actions0Window0"."WindowTypes" = 33;
      "khotkeysrc"."Data_2_1Conditions"."Comment" = "";
      "khotkeysrc"."Data_2_1Conditions"."ConditionsCount" = 0;
      "khotkeysrc"."Data_2_1Triggers"."Comment" = "Simple_action";
      "khotkeysrc"."Data_2_1Triggers"."TriggersCount" = 1;
      "khotkeysrc"."Data_2_1Triggers0"."Key" = "Ctrl+Alt+I";
      "khotkeysrc"."Data_2_1Triggers0"."Type" = "SHORTCUT";
      "khotkeysrc"."Data_2_1Triggers0"."Uuid" = "{edd7522b-b1b3-4273-838a-358ee66356b2}";
      "khotkeysrc"."Data_2_2"."Comment" = "After pressing Alt+Ctrl+H the input of 'Hello' will be simulated, as if you typed it.  This is especially useful if you have call to frequently type a word (for instance, 'unsigned').  Every keypress in the input is separated by a colon ':'. Note that the keypresses literally mean keypresses, so you have to write what you would press on the keyboard. In the table below, the left column shows the input and the right column shows what to type.\n\n\"enter\" (i.e. new line)                Enter or Return\na (i.e. small a)                          A\nA (i.e. capital a)                       Shift+A\n: (colon)                                  Shift+;\n' '  (space)                              Space";
      "khotkeysrc"."Data_2_2"."Enabled" = false;
      "khotkeysrc"."Data_2_2"."Name" = "Type 'Hello'";
      "khotkeysrc"."Data_2_2"."Type" = "SIMPLE_ACTION_DATA";
      "khotkeysrc"."Data_2_2Actions"."ActionsCount" = 1;
      "khotkeysrc"."Data_2_2Actions0"."DestinationWindow" = 2;
      "khotkeysrc"."Data_2_2Actions0"."Input" = "Shift+H:E:L:L:O\n";
      "khotkeysrc"."Data_2_2Actions0"."Type" = "KEYBOARD_INPUT";
      "khotkeysrc"."Data_2_2Conditions"."Comment" = "";
      "khotkeysrc"."Data_2_2Conditions"."ConditionsCount" = 0;
      "khotkeysrc"."Data_2_2Triggers"."Comment" = "Simple_action";
      "khotkeysrc"."Data_2_2Triggers"."TriggersCount" = 1;
      "khotkeysrc"."Data_2_2Triggers0"."Key" = "Ctrl+Alt+H";
      "khotkeysrc"."Data_2_2Triggers0"."Type" = "SHORTCUT";
      "khotkeysrc"."Data_2_2Triggers0"."Uuid" = "{fd8182a4-81c3-4540-8e28-f7e5e72585c5}";
      "khotkeysrc"."Data_2_3"."Comment" = "This action runs Konsole, after pressing Ctrl+Alt+T.";
      "khotkeysrc"."Data_2_3"."Enabled" = false;
      "khotkeysrc"."Data_2_3"."Name" = "Run Konsole";
      "khotkeysrc"."Data_2_3"."Type" = "SIMPLE_ACTION_DATA";
      "khotkeysrc"."Data_2_3Actions"."ActionsCount" = 1;
      "khotkeysrc"."Data_2_3Actions0"."CommandURL" = "konsole";
      "khotkeysrc"."Data_2_3Actions0"."Type" = "COMMAND_URL";
      "khotkeysrc"."Data_2_3Conditions"."Comment" = "";
      "khotkeysrc"."Data_2_3Conditions"."ConditionsCount" = 0;
      "khotkeysrc"."Data_2_3Triggers"."Comment" = "Simple_action";
      "khotkeysrc"."Data_2_3Triggers"."TriggersCount" = 1;
      "khotkeysrc"."Data_2_3Triggers0"."Key" = "Ctrl+Alt+T";
      "khotkeysrc"."Data_2_3Triggers0"."Type" = "SHORTCUT";
      "khotkeysrc"."Data_2_3Triggers0"."Uuid" = "{cdaec3a6-214e-4cc5-a877-c1df7064993e}";
      "khotkeysrc"."Data_2_4"."Comment" = "Read the comment on the \"Type 'Hello'\" action first.\n\nQt Designer uses Ctrl+F4 for closing windows.  In KDE, however, Ctrl+F4 is the shortcut for going to virtual desktop 4, so this shortcut does not work in Qt Designer.  Further, Qt Designer does not use KDE's standard Ctrl+W for closing the window.\n\nThis problem can be solved by remapping Ctrl+W to Ctrl+F4 when the active window is Qt Designer. When Qt Designer is active, every time Ctrl+W is pressed, Ctrl+F4 will be sent to Qt Designer instead. In other applications, the effect of Ctrl+W is unchanged.\n\nWe now need to specify three things: A new shortcut trigger on 'Ctrl+W', a new keyboard input action sending Ctrl+F4, and a new condition that the active window is Qt Designer.\nQt Designer seems to always have title 'Qt Designer by Trolltech', so the condition will check for the active window having that title.";
      "khotkeysrc"."Data_2_4"."Enabled" = false;
      "khotkeysrc"."Data_2_4"."Name" = "Remap Ctrl+W to Ctrl+F4 in Qt Designer";
      "khotkeysrc"."Data_2_4"."Type" = "GENERIC_ACTION_DATA";
      "khotkeysrc"."Data_2_4Actions"."ActionsCount" = 1;
      "khotkeysrc"."Data_2_4Actions0"."DestinationWindow" = 2;
      "khotkeysrc"."Data_2_4Actions0"."Input" = "Ctrl+F4";
      "khotkeysrc"."Data_2_4Actions0"."Type" = "KEYBOARD_INPUT";
      "khotkeysrc"."Data_2_4Conditions"."Comment" = "";
      "khotkeysrc"."Data_2_4Conditions"."ConditionsCount" = 1;
      "khotkeysrc"."Data_2_4Conditions0"."Type" = "ACTIVE_WINDOW";
      "khotkeysrc"."Data_2_4Conditions0Window"."Comment" = "Qt Designer";
      "khotkeysrc"."Data_2_4Conditions0Window"."WindowsCount" = 1;
      "khotkeysrc"."Data_2_4Conditions0Window0"."Class" = "";
      "khotkeysrc"."Data_2_4Conditions0Window0"."ClassType" = 0;
      "khotkeysrc"."Data_2_4Conditions0Window0"."Comment" = "";
      "khotkeysrc"."Data_2_4Conditions0Window0"."Role" = "";
      "khotkeysrc"."Data_2_4Conditions0Window0"."RoleType" = 0;
      "khotkeysrc"."Data_2_4Conditions0Window0"."Title" = "Qt Designer by Trolltech";
      "khotkeysrc"."Data_2_4Conditions0Window0"."TitleType" = 2;
      "khotkeysrc"."Data_2_4Conditions0Window0"."Type" = "SIMPLE";
      "khotkeysrc"."Data_2_4Conditions0Window0"."WindowTypes" = 33;
      "khotkeysrc"."Data_2_4Triggers"."Comment" = "";
      "khotkeysrc"."Data_2_4Triggers"."TriggersCount" = 1;
      "khotkeysrc"."Data_2_4Triggers0"."Key" = "Ctrl+W";
      "khotkeysrc"."Data_2_4Triggers0"."Type" = "SHORTCUT";
      "khotkeysrc"."Data_2_4Triggers0"."Uuid" = "{be4d63e1-1548-4c32-bdae-670b212885a5}";
      "khotkeysrc"."Data_2_5"."Comment" = "By pressing Alt+Ctrl+W a D-Bus call will be performed that will show the minicli. You can use any kind of D-Bus call, just like using the command line 'qdbus' tool.";
      "khotkeysrc"."Data_2_5"."Enabled" = false;
      "khotkeysrc"."Data_2_5"."Name" = "Perform D-Bus call 'qdbus org.kde.krunner /App display'";
      "khotkeysrc"."Data_2_5"."Type" = "SIMPLE_ACTION_DATA";
      "khotkeysrc"."Data_2_5Actions"."ActionsCount" = 1;
      "khotkeysrc"."Data_2_5Actions0"."Arguments" = "";
      "khotkeysrc"."Data_2_5Actions0"."Call" = "popupExecuteCommand";
      "khotkeysrc"."Data_2_5Actions0"."RemoteApp" = "org.kde.krunner";
      "khotkeysrc"."Data_2_5Actions0"."RemoteObj" = "/App";
      "khotkeysrc"."Data_2_5Actions0"."Type" = "DBUS";
      "khotkeysrc"."Data_2_5Conditions"."Comment" = "";
      "khotkeysrc"."Data_2_5Conditions"."ConditionsCount" = 0;
      "khotkeysrc"."Data_2_5Triggers"."Comment" = "Simple_action";
      "khotkeysrc"."Data_2_5Triggers"."TriggersCount" = 1;
      "khotkeysrc"."Data_2_5Triggers0"."Key" = "Ctrl+Alt+W";
      "khotkeysrc"."Data_2_5Triggers0"."Type" = "SHORTCUT";
      "khotkeysrc"."Data_2_5Triggers0"."Uuid" = "{04f1cf14-2324-43a4-854e-867e289623db}";
      "khotkeysrc"."Data_2_6"."Comment" = "Read the comment on the \"Type 'Hello'\" action first.\n\nJust like the \"Type 'Hello'\" action, this one simulates keyboard input, specifically, after pressing Ctrl+Alt+B, it sends B to XMMS (B in XMMS jumps to the next song). The 'Send to specific window' checkbox is checked and a window with its class containing 'XMMS_Player' is specified; this will make the input always be sent to this window. This way, you can control XMMS even if, for instance, it is on a different virtual desktop.\n\n(Run 'xprop' and click on the XMMS window and search for WM_CLASS to see 'XMMS_Player').";
      "khotkeysrc"."Data_2_6"."Enabled" = false;
      "khotkeysrc"."Data_2_6"."Name" = "Next in XMMS";
      "khotkeysrc"."Data_2_6"."Type" = "SIMPLE_ACTION_DATA";
      "khotkeysrc"."Data_2_6Actions"."ActionsCount" = 1;
      "khotkeysrc"."Data_2_6Actions0"."DestinationWindow" = 1;
      "khotkeysrc"."Data_2_6Actions0"."Input" = "B";
      "khotkeysrc"."Data_2_6Actions0"."Type" = "KEYBOARD_INPUT";
      "khotkeysrc"."Data_2_6Actions0DestinationWindow"."Comment" = "XMMS window";
      "khotkeysrc"."Data_2_6Actions0DestinationWindow"."WindowsCount" = 1;
      "khotkeysrc"."Data_2_6Actions0DestinationWindow0"."Class" = "XMMS_Player";
      "khotkeysrc"."Data_2_6Actions0DestinationWindow0"."ClassType" = 1;
      "khotkeysrc"."Data_2_6Actions0DestinationWindow0"."Comment" = "XMMS Player window";
      "khotkeysrc"."Data_2_6Actions0DestinationWindow0"."Role" = "";
      "khotkeysrc"."Data_2_6Actions0DestinationWindow0"."RoleType" = 0;
      "khotkeysrc"."Data_2_6Actions0DestinationWindow0"."Title" = "";
      "khotkeysrc"."Data_2_6Actions0DestinationWindow0"."TitleType" = 0;
      "khotkeysrc"."Data_2_6Actions0DestinationWindow0"."Type" = "SIMPLE";
      "khotkeysrc"."Data_2_6Actions0DestinationWindow0"."WindowTypes" = 33;
      "khotkeysrc"."Data_2_6Conditions"."Comment" = "";
      "khotkeysrc"."Data_2_6Conditions"."ConditionsCount" = 0;
      "khotkeysrc"."Data_2_6Triggers"."Comment" = "Simple_action";
      "khotkeysrc"."Data_2_6Triggers"."TriggersCount" = 1;
      "khotkeysrc"."Data_2_6Triggers0"."Key" = "Ctrl+Alt+B";
      "khotkeysrc"."Data_2_6Triggers0"."Type" = "SHORTCUT";
      "khotkeysrc"."Data_2_6Triggers0"."Uuid" = "{c6793be6-3845-4af5-97c0-3d09f9118e6b}";
      "khotkeysrc"."Data_2_7"."Comment" = "Konqueror in KDE3.1 has tabs, and now you can also have gestures.\n\nJust press the middle mouse button and start drawing one of the gestures, and after you are finished, release the mouse button. If you only need to paste the selection, it still works, just click the middle mouse button. (You can change the mouse button to use in the global settings).\n\nRight now, there are the following gestures available:\nmove right and back left - Forward (Alt+Right)\nmove left and back right - Back (Alt+Left)\nmove up and back down  - Up (Alt+Up)\ncircle counterclockwise - Reload (F5)\n\nThe gesture shapes can be entered by performing them in the configuration dialog. You can also look at your numeric pad to help you: gestures are recognized like a 3x3 grid of fields, numbered 1 to 9.\n\nNote that you must perform exactly the gesture to trigger the action. Because of this, it is possible to enter more gestures for the action. You should try to avoid complicated gestures where you change the direction of mouse movement more than once.  For instance, 45654 or 74123 are simple to perform, but 1236987 may be already quite difficult.\n\nThe conditions for all gestures are defined in this group. All these gestures are active only if the active window is Konqueror (class contains 'konqueror').";
      "khotkeysrc"."Data_2_7"."DataCount" = 4;
      "khotkeysrc"."Data_2_7"."Enabled" = false;
      "khotkeysrc"."Data_2_7"."Name" = "Konqi Gestures";
      "khotkeysrc"."Data_2_7"."SystemGroup" = 0;
      "khotkeysrc"."Data_2_7"."Type" = "ACTION_DATA_GROUP";
      "khotkeysrc"."Data_2_7Conditions"."Comment" = "Konqueror window";
      "khotkeysrc"."Data_2_7Conditions"."ConditionsCount" = 1;
      "khotkeysrc"."Data_2_7Conditions0"."Type" = "ACTIVE_WINDOW";
      "khotkeysrc"."Data_2_7Conditions0Window"."Comment" = "Konqueror";
      "khotkeysrc"."Data_2_7Conditions0Window"."WindowsCount" = 1;
      "khotkeysrc"."Data_2_7Conditions0Window0"."Class" = "konqueror";
      "khotkeysrc"."Data_2_7Conditions0Window0"."ClassType" = 1;
      "khotkeysrc"."Data_2_7Conditions0Window0"."Comment" = "Konqueror";
      "khotkeysrc"."Data_2_7Conditions0Window0"."Role" = "";
      "khotkeysrc"."Data_2_7Conditions0Window0"."RoleType" = 0;
      "khotkeysrc"."Data_2_7Conditions0Window0"."Title" = "";
      "khotkeysrc"."Data_2_7Conditions0Window0"."TitleType" = 0;
      "khotkeysrc"."Data_2_7Conditions0Window0"."Type" = "SIMPLE";
      "khotkeysrc"."Data_2_7Conditions0Window0"."WindowTypes" = 33;
      "khotkeysrc"."Data_2_7_1"."Comment" = "";
      "khotkeysrc"."Data_2_7_1"."Enabled" = false;
      "khotkeysrc"."Data_2_7_1"."Name" = "Back";
      "khotkeysrc"."Data_2_7_1"."Type" = "SIMPLE_ACTION_DATA";
      "khotkeysrc"."Data_2_7_1Actions"."ActionsCount" = 1;
      "khotkeysrc"."Data_2_7_1Actions0"."DestinationWindow" = 2;
      "khotkeysrc"."Data_2_7_1Actions0"."Input" = "Alt+Left";
      "khotkeysrc"."Data_2_7_1Actions0"."Type" = "KEYBOARD_INPUT";
      "khotkeysrc"."Data_2_7_1Conditions"."Comment" = "";
      "khotkeysrc"."Data_2_7_1Conditions"."ConditionsCount" = 0;
      "khotkeysrc"."Data_2_7_1Triggers"."Comment" = "Gesture_triggers";
      "khotkeysrc"."Data_2_7_1Triggers"."TriggersCount" = 3;
      "khotkeysrc"."Data_2_7_1Triggers0"."GesturePointData" = "0,0.0625,1,1,0.5,0.0625,0.0625,1,0.875,0.5,0.125,0.0625,1,0.75,0.5,0.1875,0.0625,1,0.625,0.5,0.25,0.0625,1,0.5,0.5,0.3125,0.0625,1,0.375,0.5,0.375,0.0625,1,0.25,0.5,0.4375,0.0625,1,0.125,0.5,0.5,0.0625,0,0,0.5,0.5625,0.0625,0,0.125,0.5,0.625,0.0625,0,0.25,0.5,0.6875,0.0625,0,0.375,0.5,0.75,0.0625,0,0.5,0.5,0.8125,0.0625,0,0.625,0.5,0.875,0.0625,0,0.75,0.5,0.9375,0.0625,0,0.875,0.5,1,0,0,1,0.5";
      "khotkeysrc"."Data_2_7_1Triggers0"."Type" = "GESTURE";
      "khotkeysrc"."Data_2_7_1Triggers1"."GesturePointData" = "0,0.0833333,1,0.5,0.5,0.0833333,0.0833333,1,0.375,0.5,0.166667,0.0833333,1,0.25,0.5,0.25,0.0833333,1,0.125,0.5,0.333333,0.0833333,0,0,0.5,0.416667,0.0833333,0,0.125,0.5,0.5,0.0833333,0,0.25,0.5,0.583333,0.0833333,0,0.375,0.5,0.666667,0.0833333,0,0.5,0.5,0.75,0.0833333,0,0.625,0.5,0.833333,0.0833333,0,0.75,0.5,0.916667,0.0833333,0,0.875,0.5,1,0,0,1,0.5";
      "khotkeysrc"."Data_2_7_1Triggers1"."Type" = "GESTURE";
      "khotkeysrc"."Data_2_7_1Triggers2"."GesturePointData" = "0,0.0833333,1,1,0.5,0.0833333,0.0833333,1,0.875,0.5,0.166667,0.0833333,1,0.75,0.5,0.25,0.0833333,1,0.625,0.5,0.333333,0.0833333,1,0.5,0.5,0.416667,0.0833333,1,0.375,0.5,0.5,0.0833333,1,0.25,0.5,0.583333,0.0833333,1,0.125,0.5,0.666667,0.0833333,0,0,0.5,0.75,0.0833333,0,0.125,0.5,0.833333,0.0833333,0,0.25,0.5,0.916667,0.0833333,0,0.375,0.5,1,0,0,0.5,0.5";
      "khotkeysrc"."Data_2_7_1Triggers2"."Type" = "GESTURE";
      "khotkeysrc"."Data_2_7_2"."Comment" = "";
      "khotkeysrc"."Data_2_7_2"."Enabled" = false;
      "khotkeysrc"."Data_2_7_2"."Name" = "Forward";
      "khotkeysrc"."Data_2_7_2"."Type" = "SIMPLE_ACTION_DATA";
      "khotkeysrc"."Data_2_7_2Actions"."ActionsCount" = 1;
      "khotkeysrc"."Data_2_7_2Actions0"."DestinationWindow" = 2;
      "khotkeysrc"."Data_2_7_2Actions0"."Input" = "Alt+Right";
      "khotkeysrc"."Data_2_7_2Actions0"."Type" = "KEYBOARD_INPUT";
      "khotkeysrc"."Data_2_7_2Conditions"."Comment" = "";
      "khotkeysrc"."Data_2_7_2Conditions"."ConditionsCount" = 0;
      "khotkeysrc"."Data_2_7_2Triggers"."Comment" = "Gesture_triggers";
      "khotkeysrc"."Data_2_7_2Triggers"."TriggersCount" = 3;
      "khotkeysrc"."Data_2_7_2Triggers0"."GesturePointData" = "0,0.0625,0,0,0.5,0.0625,0.0625,0,0.125,0.5,0.125,0.0625,0,0.25,0.5,0.1875,0.0625,0,0.375,0.5,0.25,0.0625,0,0.5,0.5,0.3125,0.0625,0,0.625,0.5,0.375,0.0625,0,0.75,0.5,0.4375,0.0625,0,0.875,0.5,0.5,0.0625,1,1,0.5,0.5625,0.0625,1,0.875,0.5,0.625,0.0625,1,0.75,0.5,0.6875,0.0625,1,0.625,0.5,0.75,0.0625,1,0.5,0.5,0.8125,0.0625,1,0.375,0.5,0.875,0.0625,1,0.25,0.5,0.9375,0.0625,1,0.125,0.5,1,0,0,0,0.5";
      "khotkeysrc"."Data_2_7_2Triggers0"."Type" = "GESTURE";
      "khotkeysrc"."Data_2_7_2Triggers1"."GesturePointData" = "0,0.0833333,0,0.5,0.5,0.0833333,0.0833333,0,0.625,0.5,0.166667,0.0833333,0,0.75,0.5,0.25,0.0833333,0,0.875,0.5,0.333333,0.0833333,1,1,0.5,0.416667,0.0833333,1,0.875,0.5,0.5,0.0833333,1,0.75,0.5,0.583333,0.0833333,1,0.625,0.5,0.666667,0.0833333,1,0.5,0.5,0.75,0.0833333,1,0.375,0.5,0.833333,0.0833333,1,0.25,0.5,0.916667,0.0833333,1,0.125,0.5,1,0,0,0,0.5";
      "khotkeysrc"."Data_2_7_2Triggers1"."Type" = "GESTURE";
      "khotkeysrc"."Data_2_7_2Triggers2"."GesturePointData" = "0,0.0833333,0,0,0.5,0.0833333,0.0833333,0,0.125,0.5,0.166667,0.0833333,0,0.25,0.5,0.25,0.0833333,0,0.375,0.5,0.333333,0.0833333,0,0.5,0.5,0.416667,0.0833333,0,0.625,0.5,0.5,0.0833333,0,0.75,0.5,0.583333,0.0833333,0,0.875,0.5,0.666667,0.0833333,1,1,0.5,0.75,0.0833333,1,0.875,0.5,0.833333,0.0833333,1,0.75,0.5,0.916667,0.0833333,1,0.625,0.5,1,0,0,0.5,0.5";
      "khotkeysrc"."Data_2_7_2Triggers2"."Type" = "GESTURE";
      "khotkeysrc"."Data_2_7_3"."Comment" = "";
      "khotkeysrc"."Data_2_7_3"."Enabled" = false;
      "khotkeysrc"."Data_2_7_3"."Name" = "Up";
      "khotkeysrc"."Data_2_7_3"."Type" = "SIMPLE_ACTION_DATA";
      "khotkeysrc"."Data_2_7_3Actions"."ActionsCount" = 1;
      "khotkeysrc"."Data_2_7_3Actions0"."DestinationWindow" = 2;
      "khotkeysrc"."Data_2_7_3Actions0"."Input" = "Alt+Up";
      "khotkeysrc"."Data_2_7_3Actions0"."Type" = "KEYBOARD_INPUT";
      "khotkeysrc"."Data_2_7_3Conditions"."Comment" = "";
      "khotkeysrc"."Data_2_7_3Conditions"."ConditionsCount" = 0;
      "khotkeysrc"."Data_2_7_3Triggers"."Comment" = "Gesture_triggers";
      "khotkeysrc"."Data_2_7_3Triggers"."TriggersCount" = 3;
      "khotkeysrc"."Data_2_7_3Triggers0"."GesturePointData" = "0,0.0625,-0.5,0.5,1,0.0625,0.0625,-0.5,0.5,0.875,0.125,0.0625,-0.5,0.5,0.75,0.1875,0.0625,-0.5,0.5,0.625,0.25,0.0625,-0.5,0.5,0.5,0.3125,0.0625,-0.5,0.5,0.375,0.375,0.0625,-0.5,0.5,0.25,0.4375,0.0625,-0.5,0.5,0.125,0.5,0.0625,0.5,0.5,0,0.5625,0.0625,0.5,0.5,0.125,0.625,0.0625,0.5,0.5,0.25,0.6875,0.0625,0.5,0.5,0.375,0.75,0.0625,0.5,0.5,0.5,0.8125,0.0625,0.5,0.5,0.625,0.875,0.0625,0.5,0.5,0.75,0.9375,0.0625,0.5,0.5,0.875,1,0,0,0.5,1";
      "khotkeysrc"."Data_2_7_3Triggers0"."Type" = "GESTURE";
      "khotkeysrc"."Data_2_7_3Triggers1"."GesturePointData" = "0,0.0833333,-0.5,0.5,1,0.0833333,0.0833333,-0.5,0.5,0.875,0.166667,0.0833333,-0.5,0.5,0.75,0.25,0.0833333,-0.5,0.5,0.625,0.333333,0.0833333,-0.5,0.5,0.5,0.416667,0.0833333,-0.5,0.5,0.375,0.5,0.0833333,-0.5,0.5,0.25,0.583333,0.0833333,-0.5,0.5,0.125,0.666667,0.0833333,0.5,0.5,0,0.75,0.0833333,0.5,0.5,0.125,0.833333,0.0833333,0.5,0.5,0.25,0.916667,0.0833333,0.5,0.5,0.375,1,0,0,0.5,0.5";
      "khotkeysrc"."Data_2_7_3Triggers1"."Type" = "GESTURE";
      "khotkeysrc"."Data_2_7_3Triggers2"."GesturePointData" = "0,0.0833333,-0.5,0.5,0.5,0.0833333,0.0833333,-0.5,0.5,0.375,0.166667,0.0833333,-0.5,0.5,0.25,0.25,0.0833333,-0.5,0.5,0.125,0.333333,0.0833333,0.5,0.5,0,0.416667,0.0833333,0.5,0.5,0.125,0.5,0.0833333,0.5,0.5,0.25,0.583333,0.0833333,0.5,0.5,0.375,0.666667,0.0833333,0.5,0.5,0.5,0.75,0.0833333,0.5,0.5,0.625,0.833333,0.0833333,0.5,0.5,0.75,0.916667,0.0833333,0.5,0.5,0.875,1,0,0,0.5,1";
      "khotkeysrc"."Data_2_7_3Triggers2"."Type" = "GESTURE";
      "khotkeysrc"."Data_2_7_4"."Comment" = "";
      "khotkeysrc"."Data_2_7_4"."Enabled" = false;
      "khotkeysrc"."Data_2_7_4"."Name" = "Reload";
      "khotkeysrc"."Data_2_7_4"."Type" = "SIMPLE_ACTION_DATA";
      "khotkeysrc"."Data_2_7_4Actions"."ActionsCount" = 1;
      "khotkeysrc"."Data_2_7_4Actions0"."DestinationWindow" = 2;
      "khotkeysrc"."Data_2_7_4Actions0"."Input" = "F5";
      "khotkeysrc"."Data_2_7_4Actions0"."Type" = "KEYBOARD_INPUT";
      "khotkeysrc"."Data_2_7_4Conditions"."Comment" = "";
      "khotkeysrc"."Data_2_7_4Conditions"."ConditionsCount" = 0;
      "khotkeysrc"."Data_2_7_4Triggers"."Comment" = "Gesture_triggers";
      "khotkeysrc"."Data_2_7_4Triggers"."TriggersCount" = 3;
      "khotkeysrc"."Data_2_7_4Triggers0"."GesturePointData" = "0,0.03125,0,0,1,0.03125,0.03125,0,0.125,1,0.0625,0.03125,0,0.25,1,0.09375,0.03125,0,0.375,1,0.125,0.03125,0,0.5,1,0.15625,0.03125,0,0.625,1,0.1875,0.03125,0,0.75,1,0.21875,0.03125,0,0.875,1,0.25,0.03125,-0.5,1,1,0.28125,0.03125,-0.5,1,0.875,0.3125,0.03125,-0.5,1,0.75,0.34375,0.03125,-0.5,1,0.625,0.375,0.03125,-0.5,1,0.5,0.40625,0.03125,-0.5,1,0.375,0.4375,0.03125,-0.5,1,0.25,0.46875,0.03125,-0.5,1,0.125,0.5,0.03125,1,1,0,0.53125,0.03125,1,0.875,0,0.5625,0.03125,1,0.75,0,0.59375,0.03125,1,0.625,0,0.625,0.03125,1,0.5,0,0.65625,0.03125,1,0.375,0,0.6875,0.03125,1,0.25,0,0.71875,0.03125,1,0.125,0,0.75,0.03125,0.5,0,0,0.78125,0.03125,0.5,0,0.125,0.8125,0.03125,0.5,0,0.25,0.84375,0.03125,0.5,0,0.375,0.875,0.03125,0.5,0,0.5,0.90625,0.03125,0.5,0,0.625,0.9375,0.03125,0.5,0,0.75,0.96875,0.03125,0.5,0,0.875,1,0,0,0,1";
      "khotkeysrc"."Data_2_7_4Triggers0"."Type" = "GESTURE";
      "khotkeysrc"."Data_2_7_4Triggers1"."GesturePointData" = "0,0.0277778,0,0,1,0.0277778,0.0277778,0,0.125,1,0.0555556,0.0277778,0,0.25,1,0.0833333,0.0277778,0,0.375,1,0.111111,0.0277778,0,0.5,1,0.138889,0.0277778,0,0.625,1,0.166667,0.0277778,0,0.75,1,0.194444,0.0277778,0,0.875,1,0.222222,0.0277778,-0.5,1,1,0.25,0.0277778,-0.5,1,0.875,0.277778,0.0277778,-0.5,1,0.75,0.305556,0.0277778,-0.5,1,0.625,0.333333,0.0277778,-0.5,1,0.5,0.361111,0.0277778,-0.5,1,0.375,0.388889,0.0277778,-0.5,1,0.25,0.416667,0.0277778,-0.5,1,0.125,0.444444,0.0277778,1,1,0,0.472222,0.0277778,1,0.875,0,0.5,0.0277778,1,0.75,0,0.527778,0.0277778,1,0.625,0,0.555556,0.0277778,1,0.5,0,0.583333,0.0277778,1,0.375,0,0.611111,0.0277778,1,0.25,0,0.638889,0.0277778,1,0.125,0,0.666667,0.0277778,0.5,0,0,0.694444,0.0277778,0.5,0,0.125,0.722222,0.0277778,0.5,0,0.25,0.75,0.0277778,0.5,0,0.375,0.777778,0.0277778,0.5,0,0.5,0.805556,0.0277778,0.5,0,0.625,0.833333,0.0277778,0.5,0,0.75,0.861111,0.0277778,0.5,0,0.875,0.888889,0.0277778,0,0,1,0.916667,0.0277778,0,0.125,1,0.944444,0.0277778,0,0.25,1,0.972222,0.0277778,0,0.375,1,1,0,0,0.5,1";
      "khotkeysrc"."Data_2_7_4Triggers1"."Type" = "GESTURE";
      "khotkeysrc"."Data_2_7_4Triggers2"."GesturePointData" = "0,0.0277778,0.5,0,0.5,0.0277778,0.0277778,0.5,0,0.625,0.0555556,0.0277778,0.5,0,0.75,0.0833333,0.0277778,0.5,0,0.875,0.111111,0.0277778,0,0,1,0.138889,0.0277778,0,0.125,1,0.166667,0.0277778,0,0.25,1,0.194444,0.0277778,0,0.375,1,0.222222,0.0277778,0,0.5,1,0.25,0.0277778,0,0.625,1,0.277778,0.0277778,0,0.75,1,0.305556,0.0277778,0,0.875,1,0.333333,0.0277778,-0.5,1,1,0.361111,0.0277778,-0.5,1,0.875,0.388889,0.0277778,-0.5,1,0.75,0.416667,0.0277778,-0.5,1,0.625,0.444444,0.0277778,-0.5,1,0.5,0.472222,0.0277778,-0.5,1,0.375,0.5,0.0277778,-0.5,1,0.25,0.527778,0.0277778,-0.5,1,0.125,0.555556,0.0277778,1,1,0,0.583333,0.0277778,1,0.875,0,0.611111,0.0277778,1,0.75,0,0.638889,0.0277778,1,0.625,0,0.666667,0.0277778,1,0.5,0,0.694444,0.0277778,1,0.375,0,0.722222,0.0277778,1,0.25,0,0.75,0.0277778,1,0.125,0,0.777778,0.0277778,0.5,0,0,0.805556,0.0277778,0.5,0,0.125,0.833333,0.0277778,0.5,0,0.25,0.861111,0.0277778,0.5,0,0.375,0.888889,0.0277778,0.5,0,0.5,0.916667,0.0277778,0.5,0,0.625,0.944444,0.0277778,0.5,0,0.75,0.972222,0.0277778,0.5,0,0.875,1,0,0,0,1";
      "khotkeysrc"."Data_2_7_4Triggers2"."Type" = "GESTURE";
      "khotkeysrc"."Data_2_8"."Comment" = "After pressing Win+E (Tux+E) a WWW browser will be launched, and it will open http://www.kde.org . You may run all kind of commands you can run in minicli (Alt+F2).";
      "khotkeysrc"."Data_2_8"."Enabled" = false;
      "khotkeysrc"."Data_2_8"."Name" = "Go to KDE Website";
      "khotkeysrc"."Data_2_8"."Type" = "SIMPLE_ACTION_DATA";
      "khotkeysrc"."Data_2_8Actions"."ActionsCount" = 1;
      "khotkeysrc"."Data_2_8Actions0"."CommandURL" = "http://www.kde.org";
      "khotkeysrc"."Data_2_8Actions0"."Type" = "COMMAND_URL";
      "khotkeysrc"."Data_2_8Conditions"."Comment" = "";
      "khotkeysrc"."Data_2_8Conditions"."ConditionsCount" = 0;
      "khotkeysrc"."Data_2_8Triggers"."Comment" = "Simple_action";
      "khotkeysrc"."Data_2_8Triggers"."TriggersCount" = 1;
      "khotkeysrc"."Data_2_8Triggers0"."Key" = "Meta+E";
      "khotkeysrc"."Data_2_8Triggers0"."Type" = "SHORTCUT";
      "khotkeysrc"."Data_2_8Triggers0"."Uuid" = "{af8f36c3-5682-4153-869f-fe61c53dd3c3}";
      "khotkeysrc"."Data_3"."Comment" = "Basic Konqueror gestures.";
      "khotkeysrc"."Data_3"."DataCount" = 14;
      "khotkeysrc"."Data_3"."Enabled" = true;
      "khotkeysrc"."Data_3"."ImportId" = "konqueror_gestures_kde321";
      "khotkeysrc"."Data_3"."Name" = "Konqueror Gestures";
      "khotkeysrc"."Data_3"."SystemGroup" = 0;
      "khotkeysrc"."Data_3"."Type" = "ACTION_DATA_GROUP";
      "khotkeysrc"."Data_3Conditions"."Comment" = "Konqueror window";
      "khotkeysrc"."Data_3Conditions"."ConditionsCount" = 1;
      "khotkeysrc"."Data_3Conditions0"."Type" = "ACTIVE_WINDOW";
      "khotkeysrc"."Data_3Conditions0Window"."Comment" = "Konqueror";
      "khotkeysrc"."Data_3Conditions0Window"."WindowsCount" = 1;
      "khotkeysrc"."Data_3Conditions0Window0"."Class" = "^konquerors";
      "khotkeysrc"."Data_3Conditions0Window0"."ClassType" = 3;
      "khotkeysrc"."Data_3Conditions0Window0"."Comment" = "Konqueror";
      "khotkeysrc"."Data_3Conditions0Window0"."Role" = "konqueror-mainwindow#1";
      "khotkeysrc"."Data_3Conditions0Window0"."RoleType" = 0;
      "khotkeysrc"."Data_3Conditions0Window0"."Title" = "file:/ - Konqueror";
      "khotkeysrc"."Data_3Conditions0Window0"."TitleType" = 0;
      "khotkeysrc"."Data_3Conditions0Window0"."Type" = "SIMPLE";
      "khotkeysrc"."Data_3Conditions0Window0"."WindowTypes" = 1;
      "khotkeysrc"."Data_3_1"."Comment" = "Press, move left, release.";
      "khotkeysrc"."Data_3_1"."Enabled" = true;
      "khotkeysrc"."Data_3_1"."Name" = "Back";
      "khotkeysrc"."Data_3_1"."Type" = "SIMPLE_ACTION_DATA";
      "khotkeysrc"."Data_3_10"."Comment" = "Opera-style: Press, move up, release.\nNOTE: Conflicts with 'New Tab', and as such is disabled by default.";
      "khotkeysrc"."Data_3_10"."Enabled" = false;
      "khotkeysrc"."Data_3_10"."Name" = "Stop Loading";
      "khotkeysrc"."Data_3_10"."Type" = "SIMPLE_ACTION_DATA";
      "khotkeysrc"."Data_3_10Actions"."ActionsCount" = 1;
      "khotkeysrc"."Data_3_10Actions0"."DestinationWindow" = 2;
      "khotkeysrc"."Data_3_10Actions0"."Input" = "Escape\n";
      "khotkeysrc"."Data_3_10Actions0"."Type" = "KEYBOARD_INPUT";
      "khotkeysrc"."Data_3_10Conditions"."Comment" = "";
      "khotkeysrc"."Data_3_10Conditions"."ConditionsCount" = 0;
      "khotkeysrc"."Data_3_10Triggers"."Comment" = "Gesture_triggers";
      "khotkeysrc"."Data_3_10Triggers"."TriggersCount" = 1;
      "khotkeysrc"."Data_3_10Triggers0"."GesturePointData" = "0,0.125,-0.5,0.5,1,0.125,0.125,-0.5,0.5,0.875,0.25,0.125,-0.5,0.5,0.75,0.375,0.125,-0.5,0.5,0.625,0.5,0.125,-0.5,0.5,0.5,0.625,0.125,-0.5,0.5,0.375,0.75,0.125,-0.5,0.5,0.25,0.875,0.125,-0.5,0.5,0.125,1,0,0,0.5,0";
      "khotkeysrc"."Data_3_10Triggers0"."Type" = "GESTURE";
      "khotkeysrc"."Data_3_11"."Comment" = "Going up in URL/directory structure.\nMozilla-style: Press, move up, move left, move up, release.";
      "khotkeysrc"."Data_3_11"."Enabled" = true;
      "khotkeysrc"."Data_3_11"."Name" = "Up";
      "khotkeysrc"."Data_3_11"."Type" = "SIMPLE_ACTION_DATA";
      "khotkeysrc"."Data_3_11Actions"."ActionsCount" = 1;
      "khotkeysrc"."Data_3_11Actions0"."DestinationWindow" = 2;
      "khotkeysrc"."Data_3_11Actions0"."Input" = "Alt+Up";
      "khotkeysrc"."Data_3_11Actions0"."Type" = "KEYBOARD_INPUT";
      "khotkeysrc"."Data_3_11Conditions"."Comment" = "";
      "khotkeysrc"."Data_3_11Conditions"."ConditionsCount" = 0;
      "khotkeysrc"."Data_3_11Triggers"."Comment" = "Gesture_triggers";
      "khotkeysrc"."Data_3_11Triggers"."TriggersCount" = 1;
      "khotkeysrc"."Data_3_11Triggers0"."GesturePointData" = "0,0.0625,-0.5,1,1,0.0625,0.0625,-0.5,1,0.875,0.125,0.0625,-0.5,1,0.75,0.1875,0.0625,-0.5,1,0.625,0.25,0.0625,1,1,0.5,0.3125,0.0625,1,0.875,0.5,0.375,0.0625,1,0.75,0.5,0.4375,0.0625,1,0.625,0.5,0.5,0.0625,1,0.5,0.5,0.5625,0.0625,1,0.375,0.5,0.625,0.0625,1,0.25,0.5,0.6875,0.0625,1,0.125,0.5,0.75,0.0625,-0.5,0,0.5,0.8125,0.0625,-0.5,0,0.375,0.875,0.0625,-0.5,0,0.25,0.9375,0.0625,-0.5,0,0.125,1,0,0,0,0";
      "khotkeysrc"."Data_3_11Triggers0"."Type" = "GESTURE";
      "khotkeysrc"."Data_3_12"."Comment" = "Going up in URL/directory structure.\nOpera-style: Press, move up, move left, move up, release.\nNOTE: Conflicts with  \"Activate Previous Tab\", and as such is disabled by default.";
      "khotkeysrc"."Data_3_12"."Enabled" = false;
      "khotkeysrc"."Data_3_12"."Name" = "Up #2";
      "khotkeysrc"."Data_3_12"."Type" = "SIMPLE_ACTION_DATA";
      "khotkeysrc"."Data_3_12Actions"."ActionsCount" = 1;
      "khotkeysrc"."Data_3_12Actions0"."DestinationWindow" = 2;
      "khotkeysrc"."Data_3_12Actions0"."Input" = "Alt+Up\n";
      "khotkeysrc"."Data_3_12Actions0"."Type" = "KEYBOARD_INPUT";
      "khotkeysrc"."Data_3_12Conditions"."Comment" = "";
      "khotkeysrc"."Data_3_12Conditions"."ConditionsCount" = 0;
      "khotkeysrc"."Data_3_12Triggers"."Comment" = "Gesture_triggers";
      "khotkeysrc"."Data_3_12Triggers"."TriggersCount" = 1;
      "khotkeysrc"."Data_3_12Triggers0"."GesturePointData" = "0,0.0625,-0.5,1,1,0.0625,0.0625,-0.5,1,0.875,0.125,0.0625,-0.5,1,0.75,0.1875,0.0625,-0.5,1,0.625,0.25,0.0625,-0.5,1,0.5,0.3125,0.0625,-0.5,1,0.375,0.375,0.0625,-0.5,1,0.25,0.4375,0.0625,-0.5,1,0.125,0.5,0.0625,1,1,0,0.5625,0.0625,1,0.875,0,0.625,0.0625,1,0.75,0,0.6875,0.0625,1,0.625,0,0.75,0.0625,1,0.5,0,0.8125,0.0625,1,0.375,0,0.875,0.0625,1,0.25,0,0.9375,0.0625,1,0.125,0,1,0,0,0,0";
      "khotkeysrc"."Data_3_12Triggers0"."Type" = "GESTURE";
      "khotkeysrc"."Data_3_13"."Comment" = "Press, move up, move right, release.";
      "khotkeysrc"."Data_3_13"."Enabled" = true;
      "khotkeysrc"."Data_3_13"."Name" = "Activate Next Tab";
      "khotkeysrc"."Data_3_13"."Type" = "SIMPLE_ACTION_DATA";
      "khotkeysrc"."Data_3_13Actions"."ActionsCount" = 1;
      "khotkeysrc"."Data_3_13Actions0"."DestinationWindow" = 2;
      "khotkeysrc"."Data_3_13Actions0"."Input" = "Ctrl+.\n";
      "khotkeysrc"."Data_3_13Actions0"."Type" = "KEYBOARD_INPUT";
      "khotkeysrc"."Data_3_13Conditions"."Comment" = "";
      "khotkeysrc"."Data_3_13Conditions"."ConditionsCount" = 0;
      "khotkeysrc"."Data_3_13Triggers"."Comment" = "Gesture_triggers";
      "khotkeysrc"."Data_3_13Triggers"."TriggersCount" = 1;
      "khotkeysrc"."Data_3_13Triggers0"."GesturePointData" = "0,0.0625,-0.5,0,1,0.0625,0.0625,-0.5,0,0.875,0.125,0.0625,-0.5,0,0.75,0.1875,0.0625,-0.5,0,0.625,0.25,0.0625,-0.5,0,0.5,0.3125,0.0625,-0.5,0,0.375,0.375,0.0625,-0.5,0,0.25,0.4375,0.0625,-0.5,0,0.125,0.5,0.0625,0,0,0,0.5625,0.0625,0,0.125,0,0.625,0.0625,0,0.25,0,0.6875,0.0625,0,0.375,0,0.75,0.0625,0,0.5,0,0.8125,0.0625,0,0.625,0,0.875,0.0625,0,0.75,0,0.9375,0.0625,0,0.875,0,1,0,0,1,0";
      "khotkeysrc"."Data_3_13Triggers0"."Type" = "GESTURE";
      "khotkeysrc"."Data_3_14"."Comment" = "Press, move up, move left, release.";
      "khotkeysrc"."Data_3_14"."Enabled" = true;
      "khotkeysrc"."Data_3_14"."Name" = "Activate Previous Tab";
      "khotkeysrc"."Data_3_14"."Type" = "SIMPLE_ACTION_DATA";
      "khotkeysrc"."Data_3_14Actions"."ActionsCount" = 1;
      "khotkeysrc"."Data_3_14Actions0"."DestinationWindow" = 2;
      "khotkeysrc"."Data_3_14Actions0"."Input" = "Ctrl+,";
      "khotkeysrc"."Data_3_14Actions0"."Type" = "KEYBOARD_INPUT";
      "khotkeysrc"."Data_3_14Conditions"."Comment" = "";
      "khotkeysrc"."Data_3_14Conditions"."ConditionsCount" = 0;
      "khotkeysrc"."Data_3_14Triggers"."Comment" = "Gesture_triggers";
      "khotkeysrc"."Data_3_14Triggers"."TriggersCount" = 1;
      "khotkeysrc"."Data_3_14Triggers0"."GesturePointData" = "0,0.0625,-0.5,1,1,0.0625,0.0625,-0.5,1,0.875,0.125,0.0625,-0.5,1,0.75,0.1875,0.0625,-0.5,1,0.625,0.25,0.0625,-0.5,1,0.5,0.3125,0.0625,-0.5,1,0.375,0.375,0.0625,-0.5,1,0.25,0.4375,0.0625,-0.5,1,0.125,0.5,0.0625,1,1,0,0.5625,0.0625,1,0.875,0,0.625,0.0625,1,0.75,0,0.6875,0.0625,1,0.625,0,0.75,0.0625,1,0.5,0,0.8125,0.0625,1,0.375,0,0.875,0.0625,1,0.25,0,0.9375,0.0625,1,0.125,0,1,0,0,0,0";
      "khotkeysrc"."Data_3_14Triggers0"."Type" = "GESTURE";
      "khotkeysrc"."Data_3_1Actions"."ActionsCount" = 1;
      "khotkeysrc"."Data_3_1Actions0"."DestinationWindow" = 2;
      "khotkeysrc"."Data_3_1Actions0"."Input" = "Alt+Left";
      "khotkeysrc"."Data_3_1Actions0"."Type" = "KEYBOARD_INPUT";
      "khotkeysrc"."Data_3_1Conditions"."Comment" = "";
      "khotkeysrc"."Data_3_1Conditions"."ConditionsCount" = 0;
      "khotkeysrc"."Data_3_1Triggers"."Comment" = "Gesture_triggers";
      "khotkeysrc"."Data_3_1Triggers"."TriggersCount" = 1;
      "khotkeysrc"."Data_3_1Triggers0"."GesturePointData" = "0,0.125,1,1,0.5,0.125,0.125,1,0.875,0.5,0.25,0.125,1,0.75,0.5,0.375,0.125,1,0.625,0.5,0.5,0.125,1,0.5,0.5,0.625,0.125,1,0.375,0.5,0.75,0.125,1,0.25,0.5,0.875,0.125,1,0.125,0.5,1,0,0,0,0.5";
      "khotkeysrc"."Data_3_1Triggers0"."Type" = "GESTURE";
      "khotkeysrc"."Data_3_2"."Comment" = "Press, move down, move up, move down, release.";
      "khotkeysrc"."Data_3_2"."Enabled" = true;
      "khotkeysrc"."Data_3_2"."Name" = "Duplicate Tab";
      "khotkeysrc"."Data_3_2"."Type" = "SIMPLE_ACTION_DATA";
      "khotkeysrc"."Data_3_2Actions"."ActionsCount" = 1;
      "khotkeysrc"."Data_3_2Actions0"."DestinationWindow" = 2;
      "khotkeysrc"."Data_3_2Actions0"."Input" = "Ctrl+Shift+D\n";
      "khotkeysrc"."Data_3_2Actions0"."Type" = "KEYBOARD_INPUT";
      "khotkeysrc"."Data_3_2Conditions"."Comment" = "";
      "khotkeysrc"."Data_3_2Conditions"."ConditionsCount" = 0;
      "khotkeysrc"."Data_3_2Triggers"."Comment" = "Gesture_triggers";
      "khotkeysrc"."Data_3_2Triggers"."TriggersCount" = 1;
      "khotkeysrc"."Data_3_2Triggers0"."GesturePointData" = "0,0.0416667,0.5,0.5,0,0.0416667,0.0416667,0.5,0.5,0.125,0.0833333,0.0416667,0.5,0.5,0.25,0.125,0.0416667,0.5,0.5,0.375,0.166667,0.0416667,0.5,0.5,0.5,0.208333,0.0416667,0.5,0.5,0.625,0.25,0.0416667,0.5,0.5,0.75,0.291667,0.0416667,0.5,0.5,0.875,0.333333,0.0416667,-0.5,0.5,1,0.375,0.0416667,-0.5,0.5,0.875,0.416667,0.0416667,-0.5,0.5,0.75,0.458333,0.0416667,-0.5,0.5,0.625,0.5,0.0416667,-0.5,0.5,0.5,0.541667,0.0416667,-0.5,0.5,0.375,0.583333,0.0416667,-0.5,0.5,0.25,0.625,0.0416667,-0.5,0.5,0.125,0.666667,0.0416667,0.5,0.5,0,0.708333,0.0416667,0.5,0.5,0.125,0.75,0.0416667,0.5,0.5,0.25,0.791667,0.0416667,0.5,0.5,0.375,0.833333,0.0416667,0.5,0.5,0.5,0.875,0.0416667,0.5,0.5,0.625,0.916667,0.0416667,0.5,0.5,0.75,0.958333,0.0416667,0.5,0.5,0.875,1,0,0,0.5,1";
      "khotkeysrc"."Data_3_2Triggers0"."Type" = "GESTURE";
      "khotkeysrc"."Data_3_3"."Comment" = "Press, move down, move up, release.";
      "khotkeysrc"."Data_3_3"."Enabled" = true;
      "khotkeysrc"."Data_3_3"."Name" = "Duplicate Window";
      "khotkeysrc"."Data_3_3"."Type" = "SIMPLE_ACTION_DATA";
      "khotkeysrc"."Data_3_3Actions"."ActionsCount" = 1;
      "khotkeysrc"."Data_3_3Actions0"."DestinationWindow" = 2;
      "khotkeysrc"."Data_3_3Actions0"."Input" = "Ctrl+D\n";
      "khotkeysrc"."Data_3_3Actions0"."Type" = "KEYBOARD_INPUT";
      "khotkeysrc"."Data_3_3Conditions"."Comment" = "";
      "khotkeysrc"."Data_3_3Conditions"."ConditionsCount" = 0;
      "khotkeysrc"."Data_3_3Triggers"."Comment" = "Gesture_triggers";
      "khotkeysrc"."Data_3_3Triggers"."TriggersCount" = 1;
      "khotkeysrc"."Data_3_3Triggers0"."GesturePointData" = "0,0.0625,0.5,0.5,0,0.0625,0.0625,0.5,0.5,0.125,0.125,0.0625,0.5,0.5,0.25,0.1875,0.0625,0.5,0.5,0.375,0.25,0.0625,0.5,0.5,0.5,0.3125,0.0625,0.5,0.5,0.625,0.375,0.0625,0.5,0.5,0.75,0.4375,0.0625,0.5,0.5,0.875,0.5,0.0625,-0.5,0.5,1,0.5625,0.0625,-0.5,0.5,0.875,0.625,0.0625,-0.5,0.5,0.75,0.6875,0.0625,-0.5,0.5,0.625,0.75,0.0625,-0.5,0.5,0.5,0.8125,0.0625,-0.5,0.5,0.375,0.875,0.0625,-0.5,0.5,0.25,0.9375,0.0625,-0.5,0.5,0.125,1,0,0,0.5,0";
      "khotkeysrc"."Data_3_3Triggers0"."Type" = "GESTURE";
      "khotkeysrc"."Data_3_4"."Comment" = "Press, move right, release.";
      "khotkeysrc"."Data_3_4"."Enabled" = true;
      "khotkeysrc"."Data_3_4"."Name" = "Forward";
      "khotkeysrc"."Data_3_4"."Type" = "SIMPLE_ACTION_DATA";
      "khotkeysrc"."Data_3_4Actions"."ActionsCount" = 1;
      "khotkeysrc"."Data_3_4Actions0"."DestinationWindow" = 2;
      "khotkeysrc"."Data_3_4Actions0"."Input" = "Alt+Right";
      "khotkeysrc"."Data_3_4Actions0"."Type" = "KEYBOARD_INPUT";
      "khotkeysrc"."Data_3_4Conditions"."Comment" = "";
      "khotkeysrc"."Data_3_4Conditions"."ConditionsCount" = 0;
      "khotkeysrc"."Data_3_4Triggers"."Comment" = "Gesture_triggers";
      "khotkeysrc"."Data_3_4Triggers"."TriggersCount" = 1;
      "khotkeysrc"."Data_3_4Triggers0"."GesturePointData" = "0,0.125,0,0,0.5,0.125,0.125,0,0.125,0.5,0.25,0.125,0,0.25,0.5,0.375,0.125,0,0.375,0.5,0.5,0.125,0,0.5,0.5,0.625,0.125,0,0.625,0.5,0.75,0.125,0,0.75,0.5,0.875,0.125,0,0.875,0.5,1,0,0,1,0.5";
      "khotkeysrc"."Data_3_4Triggers0"."Type" = "GESTURE";
      "khotkeysrc"."Data_3_5"."Comment" = "Press, move down, move half up, move right, move down, release.\n(Drawing a lowercase 'h'.)";
      "khotkeysrc"."Data_3_5"."Enabled" = true;
      "khotkeysrc"."Data_3_5"."Name" = "Home";
      "khotkeysrc"."Data_3_5"."Type" = "SIMPLE_ACTION_DATA";
      "khotkeysrc"."Data_3_5Actions"."ActionsCount" = 1;
      "khotkeysrc"."Data_3_5Actions0"."DestinationWindow" = 2;
      "khotkeysrc"."Data_3_5Actions0"."Input" = "Alt+Home\n";
      "khotkeysrc"."Data_3_5Actions0"."Type" = "KEYBOARD_INPUT";
      "khotkeysrc"."Data_3_5Conditions"."Comment" = "";
      "khotkeysrc"."Data_3_5Conditions"."ConditionsCount" = 0;
      "khotkeysrc"."Data_3_5Triggers"."Comment" = "Gesture_triggers";
      "khotkeysrc"."Data_3_5Triggers"."TriggersCount" = 2;
      "khotkeysrc"."Data_3_5Triggers0"."GesturePointData" = "0,0.0461748,0.5,0,0,0.0461748,0.0461748,0.5,0,0.125,0.0923495,0.0461748,0.5,0,0.25,0.138524,0.0461748,0.5,0,0.375,0.184699,0.0461748,0.5,0,0.5,0.230874,0.0461748,0.5,0,0.625,0.277049,0.0461748,0.5,0,0.75,0.323223,0.0461748,0.5,0,0.875,0.369398,0.065301,-0.25,0,1,0.434699,0.065301,-0.25,0.125,0.875,0.5,0.065301,-0.25,0.25,0.75,0.565301,0.065301,-0.25,0.375,0.625,0.630602,0.0461748,0,0.5,0.5,0.676777,0.0461748,0,0.625,0.5,0.722951,0.0461748,0,0.75,0.5,0.769126,0.0461748,0,0.875,0.5,0.815301,0.0461748,0.5,1,0.5,0.861476,0.0461748,0.5,1,0.625,0.90765,0.0461748,0.5,1,0.75,0.953825,0.0461748,0.5,1,0.875,1,0,0,1,1";
      "khotkeysrc"."Data_3_5Triggers0"."Type" = "GESTURE";
      "khotkeysrc"."Data_3_5Triggers1"."GesturePointData" = "0,0.0416667,0.5,0,0,0.0416667,0.0416667,0.5,0,0.125,0.0833333,0.0416667,0.5,0,0.25,0.125,0.0416667,0.5,0,0.375,0.166667,0.0416667,0.5,0,0.5,0.208333,0.0416667,0.5,0,0.625,0.25,0.0416667,0.5,0,0.75,0.291667,0.0416667,0.5,0,0.875,0.333333,0.0416667,-0.5,0,1,0.375,0.0416667,-0.5,0,0.875,0.416667,0.0416667,-0.5,0,0.75,0.458333,0.0416667,-0.5,0,0.625,0.5,0.0416667,0,0,0.5,0.541667,0.0416667,0,0.125,0.5,0.583333,0.0416667,0,0.25,0.5,0.625,0.0416667,0,0.375,0.5,0.666667,0.0416667,0,0.5,0.5,0.708333,0.0416667,0,0.625,0.5,0.75,0.0416667,0,0.75,0.5,0.791667,0.0416667,0,0.875,0.5,0.833333,0.0416667,0.5,1,0.5,0.875,0.0416667,0.5,1,0.625,0.916667,0.0416667,0.5,1,0.75,0.958333,0.0416667,0.5,1,0.875,1,0,0,1,1";
      "khotkeysrc"."Data_3_5Triggers1"."Type" = "GESTURE";
      "khotkeysrc"."Data_3_6"."Comment" = "Press, move right, move down, move right, release.\nMozilla-style: Press, move down, move right, release.";
      "khotkeysrc"."Data_3_6"."Enabled" = true;
      "khotkeysrc"."Data_3_6"."Name" = "Close Tab";
      "khotkeysrc"."Data_3_6"."Type" = "SIMPLE_ACTION_DATA";
      "khotkeysrc"."Data_3_6Actions"."ActionsCount" = 1;
      "khotkeysrc"."Data_3_6Actions0"."DestinationWindow" = 2;
      "khotkeysrc"."Data_3_6Actions0"."Input" = "Ctrl+W\n";
      "khotkeysrc"."Data_3_6Actions0"."Type" = "KEYBOARD_INPUT";
      "khotkeysrc"."Data_3_6Conditions"."Comment" = "";
      "khotkeysrc"."Data_3_6Conditions"."ConditionsCount" = 0;
      "khotkeysrc"."Data_3_6Triggers"."Comment" = "Gesture_triggers";
      "khotkeysrc"."Data_3_6Triggers"."TriggersCount" = 2;
      "khotkeysrc"."Data_3_6Triggers0"."GesturePointData" = "0,0.0625,0,0,0,0.0625,0.0625,0,0.125,0,0.125,0.0625,0,0.25,0,0.1875,0.0625,0,0.375,0,0.25,0.0625,0.5,0.5,0,0.3125,0.0625,0.5,0.5,0.125,0.375,0.0625,0.5,0.5,0.25,0.4375,0.0625,0.5,0.5,0.375,0.5,0.0625,0.5,0.5,0.5,0.5625,0.0625,0.5,0.5,0.625,0.625,0.0625,0.5,0.5,0.75,0.6875,0.0625,0.5,0.5,0.875,0.75,0.0625,0,0.5,1,0.8125,0.0625,0,0.625,1,0.875,0.0625,0,0.75,1,0.9375,0.0625,0,0.875,1,1,0,0,1,1";
      "khotkeysrc"."Data_3_6Triggers0"."Type" = "GESTURE";
      "khotkeysrc"."Data_3_6Triggers1"."GesturePointData" = "0,0.0625,0.5,0,0,0.0625,0.0625,0.5,0,0.125,0.125,0.0625,0.5,0,0.25,0.1875,0.0625,0.5,0,0.375,0.25,0.0625,0.5,0,0.5,0.3125,0.0625,0.5,0,0.625,0.375,0.0625,0.5,0,0.75,0.4375,0.0625,0.5,0,0.875,0.5,0.0625,0,0,1,0.5625,0.0625,0,0.125,1,0.625,0.0625,0,0.25,1,0.6875,0.0625,0,0.375,1,0.75,0.0625,0,0.5,1,0.8125,0.0625,0,0.625,1,0.875,0.0625,0,0.75,1,0.9375,0.0625,0,0.875,1,1,0,0,1,1";
      "khotkeysrc"."Data_3_6Triggers1"."Type" = "GESTURE";
      "khotkeysrc"."Data_3_7"."Comment" = "Press, move up, release.\nConflicts with Opera-style 'Up #2', which is disabled by default.";
      "khotkeysrc"."Data_3_7"."Enabled" = true;
      "khotkeysrc"."Data_3_7"."Name" = "New Tab";
      "khotkeysrc"."Data_3_7"."Type" = "SIMPLE_ACTION_DATA";
      "khotkeysrc"."Data_3_7Actions"."ActionsCount" = 1;
      "khotkeysrc"."Data_3_7Actions0"."DestinationWindow" = 2;
      "khotkeysrc"."Data_3_7Actions0"."Input" = "Ctrl+Shift+N";
      "khotkeysrc"."Data_3_7Actions0"."Type" = "KEYBOARD_INPUT";
      "khotkeysrc"."Data_3_7Conditions"."Comment" = "";
      "khotkeysrc"."Data_3_7Conditions"."ConditionsCount" = 0;
      "khotkeysrc"."Data_3_7Triggers"."Comment" = "Gesture_triggers";
      "khotkeysrc"."Data_3_7Triggers"."TriggersCount" = 1;
      "khotkeysrc"."Data_3_7Triggers0"."GesturePointData" = "0,0.125,-0.5,0.5,1,0.125,0.125,-0.5,0.5,0.875,0.25,0.125,-0.5,0.5,0.75,0.375,0.125,-0.5,0.5,0.625,0.5,0.125,-0.5,0.5,0.5,0.625,0.125,-0.5,0.5,0.375,0.75,0.125,-0.5,0.5,0.25,0.875,0.125,-0.5,0.5,0.125,1,0,0,0.5,0";
      "khotkeysrc"."Data_3_7Triggers0"."Type" = "GESTURE";
      "khotkeysrc"."Data_3_8"."Comment" = "Press, move down, release.";
      "khotkeysrc"."Data_3_8"."Enabled" = true;
      "khotkeysrc"."Data_3_8"."Name" = "New Window";
      "khotkeysrc"."Data_3_8"."Type" = "SIMPLE_ACTION_DATA";
      "khotkeysrc"."Data_3_8Actions"."ActionsCount" = 1;
      "khotkeysrc"."Data_3_8Actions0"."DestinationWindow" = 2;
      "khotkeysrc"."Data_3_8Actions0"."Input" = "Ctrl+N\n";
      "khotkeysrc"."Data_3_8Actions0"."Type" = "KEYBOARD_INPUT";
      "khotkeysrc"."Data_3_8Conditions"."Comment" = "";
      "khotkeysrc"."Data_3_8Conditions"."ConditionsCount" = 0;
      "khotkeysrc"."Data_3_8Triggers"."Comment" = "Gesture_triggers";
      "khotkeysrc"."Data_3_8Triggers"."TriggersCount" = 1;
      "khotkeysrc"."Data_3_8Triggers0"."GesturePointData" = "0,0.125,0.5,0.5,0,0.125,0.125,0.5,0.5,0.125,0.25,0.125,0.5,0.5,0.25,0.375,0.125,0.5,0.5,0.375,0.5,0.125,0.5,0.5,0.5,0.625,0.125,0.5,0.5,0.625,0.75,0.125,0.5,0.5,0.75,0.875,0.125,0.5,0.5,0.875,1,0,0,0.5,1";
      "khotkeysrc"."Data_3_8Triggers0"."Type" = "GESTURE";
      "khotkeysrc"."Data_3_9"."Comment" = "Press, move up, move down, release.";
      "khotkeysrc"."Data_3_9"."Enabled" = true;
      "khotkeysrc"."Data_3_9"."Name" = "Reload";
      "khotkeysrc"."Data_3_9"."Type" = "SIMPLE_ACTION_DATA";
      "khotkeysrc"."Data_3_9Actions"."ActionsCount" = 1;
      "khotkeysrc"."Data_3_9Actions0"."DestinationWindow" = 2;
      "khotkeysrc"."Data_3_9Actions0"."Input" = "F5";
      "khotkeysrc"."Data_3_9Actions0"."Type" = "KEYBOARD_INPUT";
      "khotkeysrc"."Data_3_9Conditions"."Comment" = "";
      "khotkeysrc"."Data_3_9Conditions"."ConditionsCount" = 0;
      "khotkeysrc"."Data_3_9Triggers"."Comment" = "Gesture_triggers";
      "khotkeysrc"."Data_3_9Triggers"."TriggersCount" = 1;
      "khotkeysrc"."Data_3_9Triggers0"."GesturePointData" = "0,0.0625,-0.5,0.5,1,0.0625,0.0625,-0.5,0.5,0.875,0.125,0.0625,-0.5,0.5,0.75,0.1875,0.0625,-0.5,0.5,0.625,0.25,0.0625,-0.5,0.5,0.5,0.3125,0.0625,-0.5,0.5,0.375,0.375,0.0625,-0.5,0.5,0.25,0.4375,0.0625,-0.5,0.5,0.125,0.5,0.0625,0.5,0.5,0,0.5625,0.0625,0.5,0.5,0.125,0.625,0.0625,0.5,0.5,0.25,0.6875,0.0625,0.5,0.5,0.375,0.75,0.0625,0.5,0.5,0.5,0.8125,0.0625,0.5,0.5,0.625,0.875,0.0625,0.5,0.5,0.75,0.9375,0.0625,0.5,0.5,0.875,1,0,0,0.5,1";
      "khotkeysrc"."Data_3_9Triggers0"."Type" = "GESTURE";
      "khotkeysrc"."General"."AllowKDEAppsToRememberWindowPositions" = "";
      "khotkeysrc"."General"."BrowserApplication" = "";
      "khotkeysrc"."Gestures"."Disabled" = true;
      "khotkeysrc"."Gestures"."MouseButton" = 2;
      "khotkeysrc"."Gestures"."Timeout" = 300;
      "khotkeysrc"."GesturesExclude"."Comment" = "";
      "khotkeysrc"."GesturesExclude"."WindowsCount" = 0;
      "khotkeysrc"."KDE"."AnimationDurationFactor" = "";
      "khotkeysrc"."KDE"."ShowDeleteCommand" = "";
      "khotkeysrc"."KDE"."SingleClick" = "";
      "khotkeysrc"."KDE"."widgetStyle" = "";
      "khotkeysrc"."KFileDialog Settings"."Allow Expansion" = "";
      "khotkeysrc"."KFileDialog Settings"."Automatically select filename extension" = "";
      "khotkeysrc"."KFileDialog Settings"."Breadcrumb Navigation" = "";
      "khotkeysrc"."KFileDialog Settings"."Decoration position" = "";
      "khotkeysrc"."KFileDialog Settings"."LocationCombo Completionmode" = "";
      "khotkeysrc"."KFileDialog Settings"."PathCombo Completionmode" = "";
      "khotkeysrc"."KFileDialog Settings"."Show Bookmarks" = "";
      "khotkeysrc"."KFileDialog Settings"."Show Full Path" = "";
      "khotkeysrc"."KFileDialog Settings"."Show Inline Previews" = "";
      "khotkeysrc"."KFileDialog Settings"."Show Preview" = "";
      "khotkeysrc"."KFileDialog Settings"."Show Speedbar" = "";
      "khotkeysrc"."KFileDialog Settings"."Show hidden files" = "";
      "khotkeysrc"."KFileDialog Settings"."Sort by" = "";
      "khotkeysrc"."KFileDialog Settings"."Sort directories first" = "";
      "khotkeysrc"."KFileDialog Settings"."Sort hidden files last" = "";
      "khotkeysrc"."KFileDialog Settings"."Sort reversed" = "";
      "khotkeysrc"."KFileDialog Settings"."Speedbar Width" = "";
      "khotkeysrc"."KFileDialog Settings"."View Style" = "";
      "khotkeysrc"."KShortcutsDialog Settings"."Dialog Size" = "";
      "khotkeysrc"."Main"."AlreadyImported" = "defaults,kde32b1,konqueror_gestures_kde321";
      "khotkeysrc"."Main"."Disabled" = false;
      "khotkeysrc"."PreviewSettings"."MaximumRemoteSize" = "";
      "khotkeysrc"."Voice"."Shortcut" = "";
      "khotkeysrc"."WM"."activeBackground" = "";
      "khotkeysrc"."WM"."activeBlend" = "";
      "khotkeysrc"."WM"."activeForeground" = "";
      "khotkeysrc"."WM"."inactiveBackground" = "";
      "khotkeysrc"."WM"."inactiveBlend" = "";
      "khotkeysrc"."WM"."inactiveForeground" = "";
      "kiorc"."Confirmations"."ConfirmDelete" = true;
      "kiorc"."Confirmations"."ConfirmEmptyTrash" = true;
      "kiorc"."Confirmations"."ConfirmTrash" = false;
      "kiorc"."Executable scripts"."behaviourOnLaunch" = "alwaysAsk";
      "krunnerrc"."Plugins"."baloosearchEnabled" = false;
      "krunnerrc"."Plugins"."locationsEnabled" = true;
      "krunnerrc"."Plugins"."placesEnabled" = true;
      "krunnerrc"."Plugins"."recentdocumentsEnabled" = true;
      "kservicemenurc"."Show"."compressfileitemaction" = true;
      "kservicemenurc"."Show"."extractfileitemaction" = true;
      "kservicemenurc"."Show"."forgetfileitemaction" = true;
      "kservicemenurc"."Show"."installFont" = true;
      "kservicemenurc"."Show"."kactivitymanagerd_fileitem_linking_plugin" = true;
      "kservicemenurc"."Show"."kdeconnectfileitemaction" = true;
      "kservicemenurc"."Show"."kio-admin" = true;
      "kservicemenurc"."Show"."mountisoaction" = true;
      "kservicemenurc"."Show"."nextclouddolphinactionplugin" = true;
      "kservicemenurc"."Show"."runInKonsole" = true;
      "kservicemenurc"."Show"."setAsWallpaper" = true;
      "kservicemenurc"."Show"."slideshowfileitemaction" = true;
      "kservicemenurc"."Show"."tagsfileitemaction" = true;
      "ksmserverrc"."General"."loginMode" = "restoreSavedSession";
      "kwalletrc"."Wallet"."First Use" = false;
      "kwinrc"."Desktops"."Id_1" = "d1e5e218-1fd9-4946-aa47-dab2f5aac755";
      "kwinrc"."Desktops"."Id_2" = "389927fc-9c76-4f84-ae0d-011cf76868e6";
      "kwinrc"."Desktops"."Id_3" = "78f9d3d6-d0dd-4fd5-89fc-0157ada3dff5";
      "kwinrc"."Desktops"."Id_4" = "a0a9ef6d-975c-4379-8ca1-265e1938d8d1";
      "kwinrc"."Desktops"."Number" = 4;
      "kwinrc"."Desktops"."Rows" = 2;
      "kwinrc"."Effect-diminactive"."Strength" = 15;
      "kwinrc"."Effect-magiclamp"."AnimationDuration" = 20;
      "kwinrc"."NightColor"."Active" = true;
      "kwinrc"."NightColor"."LatitudeFixed" = 52.31865273558926;
      "kwinrc"."NightColor"."LongitudeFixed" = 5.44;
      "kwinrc"."NightColor"."Mode" = "Location";
      "kwinrc"."NightColor"."NightTemperature" = 2000;
      "kwinrc"."Plugins"."diminactiveEnabled" = true;
      "kwinrc"."Plugins"."dimscreenEnabled" = true;
      "kwinrc"."Plugins"."wobblywindowsEnabled" = true;
      "kwinrc"."Tiling"."padding" = 0;
      "kwinrc"."Tiling.5242ae1a-0a81-5d7b-ba61-2512b597a159"."tiles" = "{\"layoutDirection\":\"horizontal\",\"tiles\":x5b{\"width\":0.25},{\"width\":0.5},{\"width\":0.25}x5d}";
      "kwinrc"."Tiling.57cc57cb-6089-56ec-afba-00ccd06d5508"."tiles" = "{\"layoutDirection\":\"horizontal\",\"tiles\":x5b{\"width\":0.25},{\"width\":0.5},{\"width\":0.25}x5d}";
      "kwinrc"."Tiling.5c337d24-acf0-5ac2-9082-ce9cb012bc2c"."tiles" = "{\"layoutDirection\":\"horizontal\",\"tiles\":x5b{\"layoutDirection\":\"vertical\",\"tiles\":x5b{\"height\":0.5,\"layoutDirection\":\"horizontal\",\"tiles\":x5b{\"width\":0.5},{\"width\":0.5}x5d},{\"height\":0.5,\"layoutDirection\":\"horizontal\",\"tiles\":x5b{\"width\":0.5},{\"width\":0.5}x5d}x5d,\"width\":1}x5d}";
      "kwinrc"."Tiling/250b82cb-c8d2-50e6-91f9-1fb3d4d4d06b"."tiles" = "{\"layoutDirection\":\"horizontal\",\"tiles\":[{\"width\":0.4989583333333353},{\"width\":0.5010416666666646}]}";
      "kwinrc"."Tiling/5242ae1a-0a81-5d7b-ba61-2512b597a159"."tiles" = "{\"layoutDirection\":\"horizontal\",\"tiles\":x5b{\"width\":0.25},{\"width\":0.5},{\"width\":0.25}x5d}";
      "kwinrc"."Tiling/57cc57cb-6089-56ec-afba-00ccd06d5508"."tiles" = "{\"layoutDirection\":\"horizontal\",\"tiles\":[{\"width\":0.25},{\"width\":0.5},{\"width\":0.25}]}";
      "kwinrc"."Tiling/5c337d24-acf0-5ac2-9082-ce9cb012bc2c"."tiles" = "{\"layoutDirection\":\"horizontal\",\"tiles\":[{\"width\":0.5046875000000002},{\"width\":0.4953124999999998}]}";
      "kwinrc"."Tiling/98e47fc8-bbb3-5a3a-b6a8-d051b513a983"."tiles" = "{\"layoutDirection\":\"horizontal\",\"tiles\":[{\"width\":0.5005208333333331},{\"layoutDirection\":\"vertical\",\"tiles\":[{\"height\":0.5},{\"height\":0.5}],\"width\":0.4994791666666665}]}";
      "kwinrc"."Xwayland"."Scale" = 1;
      "kxkbrc"."Layout"."Options" = "compose:caps";
      "kxkbrc"."Layout"."ResetOldOptions" = true;
      "plasma-localerc"."Formats"."LANG" = "en_US.UTF-8";
      "plasma-localerc"."Formats"."LC_ADDRESS" = "nl_NL.UTF-8";
      "plasma-localerc"."Formats"."LC_MEASUREMENT" = "nl_NL.UTF-8";
      "plasma-localerc"."Formats"."LC_MONETARY" = "nl_NL.UTF-8";
      "plasma-localerc"."Formats"."LC_NAME" = "nl_NL.UTF-8";
      "plasma-localerc"."Formats"."LC_NUMERIC" = "nl_NL.UTF-8";
      "plasma-localerc"."Formats"."LC_PAPER" = "nl_NL.UTF-8";
      "plasma-localerc"."Formats"."LC_TELEPHONE" = "nl_NL.UTF-8";
      "plasma-localerc"."Formats"."LC_TIME" = "en_DK.UTF-8";
      "plasmanotifyrc"."Applications/firefox"."Seen" = true;
      "plasmanotifyrc"."Applications/floorp"."Seen" = true;
      "plasmanotifyrc"."Applications/org.qbittorrent.qBittorrent"."Seen" = true;
      "plasmanotifyrc"."Applications/vesktop"."Seen" = true;
      "plasmanotifyrc"."Applications/webcord"."Seen" = true;
      "plasmarc"."Wallpapers"."usersWallpapers" = "";
      "spectaclerc"."Annotations"."annotationToolType" = 9;
      "spectaclerc"."ImageSave"."lastImageSaveLocation" = "file:///home/lillian/Pictures/Screenshots/Screenshot_20241017_154815.png";
      "spectaclerc"."ImageSave"."translatedScreenshotsFolder" = "Screenshots";
      "spectaclerc"."VideoSave"."translatedScreencastsFolder" = "Screencasts";
      "systemsettingsrc"."KFileDialog Settings"."detailViewIconSize" = 16;
    };
    dataFile = {
      "dolphin/view_properties/global/.directory"."Settings"."HiddenFilesShown" = true;
      "kate/anonymous.katesession"."Kate Plugins"."cmaketoolsplugin" = false;
      "kate/anonymous.katesession"."Kate Plugins"."compilerexplorer" = false;
      "kate/anonymous.katesession"."Kate Plugins"."eslintplugin" = false;
      "kate/anonymous.katesession"."Kate Plugins"."externaltoolsplugin" = true;
      "kate/anonymous.katesession"."Kate Plugins"."formatplugin" = false;
      "kate/anonymous.katesession"."Kate Plugins"."katebacktracebrowserplugin" = false;
      "kate/anonymous.katesession"."Kate Plugins"."katebuildplugin" = false;
      "kate/anonymous.katesession"."Kate Plugins"."katecloseexceptplugin" = false;
      "kate/anonymous.katesession"."Kate Plugins"."katecolorpickerplugin" = false;
      "kate/anonymous.katesession"."Kate Plugins"."katectagsplugin" = false;
      "kate/anonymous.katesession"."Kate Plugins"."katefilebrowserplugin" = false;
      "kate/anonymous.katesession"."Kate Plugins"."katefiletreeplugin" = true;
      "kate/anonymous.katesession"."Kate Plugins"."kategdbplugin" = false;
      "kate/anonymous.katesession"."Kate Plugins"."kategitblameplugin" = false;
      "kate/anonymous.katesession"."Kate Plugins"."katekonsoleplugin" = true;
      "kate/anonymous.katesession"."Kate Plugins"."kateprojectplugin" = true;
      "kate/anonymous.katesession"."Kate Plugins"."katereplicodeplugin" = false;
      "kate/anonymous.katesession"."Kate Plugins"."katesearchplugin" = true;
      "kate/anonymous.katesession"."Kate Plugins"."katesnippetsplugin" = false;
      "kate/anonymous.katesession"."Kate Plugins"."katesqlplugin" = false;
      "kate/anonymous.katesession"."Kate Plugins"."katesymbolviewerplugin" = false;
      "kate/anonymous.katesession"."Kate Plugins"."katexmlcheckplugin" = false;
      "kate/anonymous.katesession"."Kate Plugins"."katexmltoolsplugin" = false;
      "kate/anonymous.katesession"."Kate Plugins"."keyboardmacrosplugin" = false;
      "kate/anonymous.katesession"."Kate Plugins"."ktexteditorpreviewplugin" = false;
      "kate/anonymous.katesession"."Kate Plugins"."latexcompletionplugin" = false;
      "kate/anonymous.katesession"."Kate Plugins"."lspclientplugin" = true;
      "kate/anonymous.katesession"."Kate Plugins"."openlinkplugin" = false;
      "kate/anonymous.katesession"."Kate Plugins"."rainbowparens" = false;
      "kate/anonymous.katesession"."Kate Plugins"."tabswitcherplugin" = true;
      "kate/anonymous.katesession"."Kate Plugins"."textfilterplugin" = true;
      "kate/anonymous.katesession"."MainWindow0"."2 screens: Window-Maximized" = true;
      "kate/anonymous.katesession"."MainWindow0"."Active ViewSpace" = 0;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-H-Splitter" = "0,2514,0";
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-Sidebar-0-Bar-0-TvList" = "kate_private_plugin_katefiletreeplugin,kateproject,kateprojectgit,lspclient_symbol_outline";
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-Sidebar-0-LastSize" = 200;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-Sidebar-0-SectSizes" = 0;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-Sidebar-0-Splitter" = 1287;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-Sidebar-1-Bar-0-TvList" = "";
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-Sidebar-1-LastSize" = 200;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-Sidebar-1-SectSizes" = 0;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-Sidebar-1-Splitter" = 1287;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-Sidebar-2-Bar-0-TvList" = "";
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-Sidebar-2-LastSize" = 200;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-Sidebar-2-SectSizes" = 0;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-Sidebar-2-Splitter" = 2514;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-Sidebar-3-Bar-0-TvList" = "output,diagnostics,kate_plugin_katesearch,kateprojectinfo,kate_private_plugin_katekonsoleplugin";
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-Sidebar-3-LastSize" = 200;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-Sidebar-3-SectSizes" = 0;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-Sidebar-3-Splitter" = 2560;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-Sidebar-Style" = 2;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-Sidebar-Visible" = true;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-ToolView-diagnostics-Position" = 3;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-ToolView-diagnostics-Show-Button-In-Sidebar" = true;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-ToolView-diagnostics-Visible" = false;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-ToolView-kate_plugin_katesearch-Position" = 3;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-ToolView-kate_plugin_katesearch-Show-Button-In-Sidebar" = true;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-ToolView-kate_plugin_katesearch-Visible" = false;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-ToolView-kate_private_plugin_katefiletreeplugin-Position" = 0;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-ToolView-kate_private_plugin_katefiletreeplugin-Show-Button-In-Sidebar" = true;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-ToolView-kate_private_plugin_katefiletreeplugin-Visible" = false;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-ToolView-kate_private_plugin_katekonsoleplugin-Position" = 3;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-ToolView-kate_private_plugin_katekonsoleplugin-Show-Button-In-Sidebar" = true;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-ToolView-kate_private_plugin_katekonsoleplugin-Visible" = false;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-ToolView-kateproject-Position" = 0;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-ToolView-kateproject-Show-Button-In-Sidebar" = true;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-ToolView-kateproject-Visible" = false;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-ToolView-kateprojectgit-Position" = 0;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-ToolView-kateprojectgit-Show-Button-In-Sidebar" = true;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-ToolView-kateprojectgit-Visible" = false;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-ToolView-kateprojectinfo-Position" = 3;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-ToolView-kateprojectinfo-Show-Button-In-Sidebar" = true;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-ToolView-kateprojectinfo-Visible" = false;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-ToolView-lspclient_symbol_outline-Position" = 0;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-ToolView-lspclient_symbol_outline-Show-Button-In-Sidebar" = true;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-ToolView-lspclient_symbol_outline-Visible" = false;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-ToolView-output-Position" = 3;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-ToolView-output-Show-Button-In-Sidebar" = true;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-ToolView-output-Visible" = false;
      "kate/anonymous.katesession"."MainWindow0"."Kate-MDI-V-Splitter" = "0,1285,0";
      "kate/anonymous.katesession"."MainWindow0"."MenuBar" = "Disabled";
      "kate/anonymous.katesession"."MainWindow0"."ToolBarsMovable" = "Disabled";
      "kate/anonymous.katesession"."MainWindow0 Settings"."2 screens: Window-Maximized" = true;
      "kate/anonymous.katesession"."MainWindow0 Settings"."MenuBar" = "Disabled";
      "kate/anonymous.katesession"."MainWindow0 Settings"."ToolBarsMovable" = "Disabled";
      "kate/anonymous.katesession"."MainWindow0 Settings"."WindowState" = 10;
      "kate/anonymous.katesession"."MainWindow0-Splitter 0"."Children" = "MainWindow0-ViewSpace 0";
      "kate/anonymous.katesession"."MainWindow0-Splitter 0"."Orientation" = 1;
      "kate/anonymous.katesession"."MainWindow0-Splitter 0"."Sizes" = 2514;
      "kate/anonymous.katesession"."MainWindow0-ViewSpace 0"."Count" = 0;
      "kate/anonymous.katesession"."MainWindow0-ViewSpace 0"."Documents" = "";
      "kate/anonymous.katesession"."Open Documents"."Count" = 0;
      "kate/anonymous.katesession"."Open MainWindows"."Count" = 1;
      "kate/anonymous.katesession"."Plugin:kateprojectplugin:"."projects" = "";
      "kate/anonymous.katesession"."Plugin:katesearchplugin:MainWindow:0"."BinaryFiles" = false;
      "kate/anonymous.katesession"."Plugin:katesearchplugin:MainWindow:0"."CurrentExcludeFilter" = "-1";
      "kate/anonymous.katesession"."Plugin:katesearchplugin:MainWindow:0"."CurrentFilter" = "-1";
      "kate/anonymous.katesession"."Plugin:katesearchplugin:MainWindow:0"."ExcludeFilters" = "";
      "kate/anonymous.katesession"."Plugin:katesearchplugin:MainWindow:0"."ExpandSearchResults" = false;
      "kate/anonymous.katesession"."Plugin:katesearchplugin:MainWindow:0"."Filters" = "";
      "kate/anonymous.katesession"."Plugin:katesearchplugin:MainWindow:0"."FollowSymLink" = false;
      "kate/anonymous.katesession"."Plugin:katesearchplugin:MainWindow:0"."HiddenFiles" = false;
      "kate/anonymous.katesession"."Plugin:katesearchplugin:MainWindow:0"."MatchCase" = false;
      "kate/anonymous.katesession"."Plugin:katesearchplugin:MainWindow:0"."Place" = 1;
      "kate/anonymous.katesession"."Plugin:katesearchplugin:MainWindow:0"."Recursive" = true;
      "kate/anonymous.katesession"."Plugin:katesearchplugin:MainWindow:0"."Replaces" = "";
      "kate/anonymous.katesession"."Plugin:katesearchplugin:MainWindow:0"."Search" = "";
      "kate/anonymous.katesession"."Plugin:katesearchplugin:MainWindow:0"."SearchAsYouTypeAllProjects" = true;
      "kate/anonymous.katesession"."Plugin:katesearchplugin:MainWindow:0"."SearchAsYouTypeCurrentFile" = true;
      "kate/anonymous.katesession"."Plugin:katesearchplugin:MainWindow:0"."SearchAsYouTypeFolder" = true;
      "kate/anonymous.katesession"."Plugin:katesearchplugin:MainWindow:0"."SearchAsYouTypeOpenFiles" = true;
      "kate/anonymous.katesession"."Plugin:katesearchplugin:MainWindow:0"."SearchAsYouTypeProject" = true;
      "kate/anonymous.katesession"."Plugin:katesearchplugin:MainWindow:0"."SearchDiskFiles" = "";
      "kate/anonymous.katesession"."Plugin:katesearchplugin:MainWindow:0"."SearchDiskFiless" = "";
      "kate/anonymous.katesession"."Plugin:katesearchplugin:MainWindow:0"."UseRegExp" = false;
    };
  };
}
